@@ -18,20 +18,35 @@
 
 poptContext ctx;
 
-Bonobo_UIContainer corba_container;
+BonoboUIComponent *global_component;
 
-static int
+static void
 cb_do_quit (GtkWindow *window, gpointer dummy)
 {
 	gtk_main_quit ();
-	return 1;
 }
 
-static int
-cb_do_dump (GtkWindow *window, BonoboWin *app)
+static void
+cb_do_dump (GtkWindow *window, BonoboWin *win)
 {
-	bonobo_win_dump (app, "on User input");
-	return 1;
+	bonobo_win_dump (win, "on User input");
+}
+
+static void
+cb_do_popup (GtkWindow *window, BonoboWin *win)
+{
+	GtkWidget *menu;
+	GtkWidget *menuitem;
+
+	menu = gtk_menu_new ();
+	menuitem = gtk_menu_item_new_with_label ("Error if you see this");
+	gtk_widget_show (menuitem);
+	gtk_menu_append (GTK_MENU (menu), menuitem);
+
+	bonobo_win_add_popup (win, GTK_MENU (menu), "/popups/MyStuff");
+
+	gtk_widget_show (GTK_WIDGET (menu));
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
 }
 
 static void
@@ -44,23 +59,21 @@ cb_set_state (GtkEntry *state_entry, GtkEntry *path_entry)
 
 	g_warning ("Set state on '%s' to '%s'", path, state);
 
-	bonobo_ui_container_set_prop (
-		corba_container, path, "state", state, NULL);
+	bonobo_ui_component_set_prop (
+		global_component, path, "state", state, NULL);
 
-	txt = bonobo_ui_container_get_prop (
-		corba_container, path, "state", NULL);
+	txt = bonobo_ui_component_get_prop (
+		global_component, path, "state", NULL);
 
 	g_warning ("Re-fetched state was '%s'", txt);
 
 	str = g_strdup_printf ("The state is now '%s'", txt);
-	bonobo_ui_container_set_status (corba_container, str, NULL);
+	bonobo_ui_component_set_status (global_component, str, NULL);
 	g_free (str);
 
 	g_free (txt);
 }
 
-
-
 static void
 toggled_cb (BonoboUIComponent           *component,
 	    const char                  *path,
@@ -94,52 +107,56 @@ update_progress (GtkProgress *progress)
 int
 main (int argc, char **argv)
 {
-	BonoboWin *app;
+	BonoboWin *win;
 	CORBA_ORB  orb;
 	BonoboUIComponent *componenta;
 	BonoboUIComponent *componentb;
 	BonoboUIComponent *componentc;
 	BonoboUIContainer *container;
+	Bonobo_UIContainer corba_container;
 	CORBA_Environment  ev;
+	char *txt;
 
 	char simplea [] =
 		"<menu>\n"
 		"	<submenu name=\"File\" label=\"_File\">\n"
-		"		<menuitem name=\"open\" label=\"_Open\" pixtype=\"stock\" pixname=\"Menu_Open\" descr=\"Wibble\"/>\n"
+		"		<menuitem name=\"open\" label=\"_Open\" pixtype=\"stock\" pixname=\"Open\" descr=\"Wibble\"/>\n"
 		"		<control name=\"MyControl\"/>\n"
+		"		<control name=\"ThisIsEmpty\"/>\n"
 		"	</submenu>\n"
 		"</menu>";
 	char simpleb [] =
 		"<submenu name=\"File\" label=\"_FileB\">\n"
-		"	<menuitem name=\"open\" label=\"_OpenB\" pixtype=\"stock\" pixname=\"Menu_Open\" descr=\"Open you fool\"/>\n"
+		"	<menuitem name=\"open\" label=\"_OpenB\" pixtype=\"stock\" pixname=\"Open\" descr=\"Open you fool\"/>\n"
 		"       <menuitem/>\n"
 		"       <menuitem name=\"toggle\" type=\"toggle\" id=\"MyFoo\" label=\"_ToggleMe\" accel=\"*Control*t\"/>\n"
-		"       <placeholder name=\"Nice\" delimit=\"both\"/>\n"
+		"       <placeholder name=\"Nice\" delimit=\"top\"/>\n"
 		"	<menuitem name=\"close\" noplace=\"1\" verb=\"Close\" label=\"_CloseB\" "
-		"        pixtype=\"stock\" pixname=\"Menu_Close\" accel=\"*Control*q\"/>\n"
+		"        pixtype=\"stock\" pixname=\"Close\" accel=\"*Control*q\"/>\n"
 		"</submenu>\n";
 	char simplec [] =
 		"<submenu name=\"File\" label=\"_FileC\">\n"
-		"    <placeholder name=\"Nice\" delimit=\"both\">\n"
+		"    <placeholder name=\"Nice\" delimit=\"top\">\n"
 		"	<menuitem name=\"fooa\" label=\"_FooA\" type=\"radio\" group=\"foogroup\" descr=\"Radio1\"/>\n"
 		"	<menuitem name=\"foob\" label=\"_FooB\" type=\"radio\" group=\"foogroup\"/>\n"
-		"	<menuitem name=\"wibble\" label=\"_Baa\" pixtype=\"stock\" pixname=\"Menu_Open\" sensitive=\"0\"/>\n"
+		"	<menuitem name=\"wibble\" verb=\"ThisForcesAnError\" label=\"_Baa\" pixtype=\"stock\" pixname=\"Open\" sensitive=\"0\"/>\n"
+		"       <separator/>\n"
 		"    </placeholder>\n"
 		"</submenu>\n";
 	char simpled [] =
-		"<menuitem name=\"save\" label=\"_SaveD\" pixtype=\"stock\" pixname=\"Menu_Save\"/>\n";
+		"<menuitem name=\"save\" label=\"_SaveD\" pixtype=\"stock\" pixname=\"Save\"/>\n";
 	char simplee [] =
-		"<menuitem name=\"fish\" label=\"_Inplace\" pixtype=\"stock\" pixname=\"Menu_Save\"/>\n";
+		"<menuitem name=\"fish\" label=\"_Inplace\" pixtype=\"stock\" pixname=\"Save\"/>\n";
 	char toola [] =
-		"<dockitem name=\"toolbar\" homogeneous=\"0\">\n"
+		"<dockitem name=\"toolbar\" homogeneous=\"0\" look=\"both\">\n"
 		"	<toolitem type=\"toggle\" name=\"foo2\" id=\"MyFoo\"pixtype=\"stock\" pixname=\"Save\" label=\"TogSave\" descr=\"My tooltip\"/>\n"
-		"	<toolitem type=\"separator\" name=\"foo3\" pixtype=\"stock\" pixname=\"Save\" label=\"Separator\"/>\n"
-		"	<toolitem type=\"std\" name=\"baa\" pixtype=\"stock\" pixname=\"Open\" label=\"baa\" descr=\"My 2nd tooltip\" verb=\"testme\"/>\n"
+		"	<separator/>\n"
+		"	<toolitem name=\"baa\" pixtype=\"stock\" pixname=\"Open\" label=\"baa\" descr=\"My 2nd tooltip\" verb=\"testme\"/>\n"
 		"	<control name=\"AControl\"/>\n"
 		"</dockitem>";
 	char toolb [] =
 		"<dockitem name=\"toolbar\" look=\"icon\" relief=\"none\">\n"
-		"	<toolitem name=\"foo1\" type=\"std\" label=\"Insensitive\" sensitive=\"0\"/>\n"
+		"	<toolitem name=\"foo1\" label=\"Insensitive\" hidden=\"0\"/>\n"
 		"	<toolitem type=\"toggle\" name=\"foo5\" id=\"MyFoo\" pixtype=\"stock\" pixname=\"Close\" label=\"TogSame\" descr=\"My tooltip\"/>\n"
 		"</dockitem>";
 	char statusa [] =
@@ -163,9 +180,9 @@ main (int argc, char **argv)
 
 	bonobo_activate ();
 
-	app = BONOBO_WIN (bonobo_win_new ("App", "My Test Application"));
+	win = BONOBO_WIN (bonobo_win_new ("Win", "My Test Application"));
 	container = bonobo_ui_container_new ();
-	bonobo_ui_container_set_app (container, app);
+	bonobo_ui_container_set_win (container, win);
 
 	corba_container = bonobo_object_corba_objref (BONOBO_OBJECT (container));
 
@@ -182,7 +199,13 @@ main (int argc, char **argv)
 
 		button = gtk_button_new_with_label ("Dump Xml tree");
 		gtk_signal_connect (GTK_OBJECT (button), "clicked",
-				    (GtkSignalFunc) cb_do_dump, app);
+				    (GtkSignalFunc) cb_do_dump, win);
+		gtk_widget_show (GTK_WIDGET (button));
+		gtk_box_pack_start_defaults (GTK_BOX (box), button);
+
+		button = gtk_button_new_with_label ("Popup");
+		gtk_signal_connect (GTK_OBJECT (button), "clicked",
+				    (GtkSignalFunc) cb_do_popup, win);
 		gtk_widget_show (GTK_WIDGET (button));
 		gtk_box_pack_start_defaults (GTK_BOX (box), button);
 
@@ -199,45 +222,59 @@ main (int argc, char **argv)
 		gtk_box_pack_start_defaults (GTK_BOX (box), state_entry);
 
 		gtk_widget_show (GTK_WIDGET (box));
-		bonobo_win_set_contents (app, box);
+		bonobo_win_set_contents (win, box);
 	}
 
 	componenta = bonobo_ui_component_new ("A");
 	componentb = bonobo_ui_component_new ("B");
 	componentc = bonobo_ui_component_new ("C");
 
+	bonobo_ui_component_set_container (componenta, corba_container);
+	bonobo_ui_component_set_container (componentb, corba_container);
+	bonobo_ui_component_set_container (componentc, corba_container);
+
+	global_component = componenta;
+
 	CORBA_exception_init (&ev);
 
 	if (g_file_exists ("ui.xml")) {
 		fprintf (stderr, "\n\n--- Add ui.xml ---\n\n\n");
-		bonobo_ui_util_set_ui (componenta, corba_container,
-				       NULL, "ui.xml", "gnomecal");
-		bonobo_ui_container_thaw (corba_container, NULL);
+		bonobo_ui_util_set_ui (componenta, NULL, "ui.xml",
+				       "gnomecal");
+		bonobo_ui_component_thaw (componenta, NULL);
 
-		gtk_widget_show (GTK_WIDGET (app));
+		bonobo_ui_component_set_prop (
+			componenta, "/menu/Preferences",
+			"pixname", "/demo/a.xpm", NULL);
+
+		gtk_widget_show (GTK_WIDGET (win));
 
 		gtk_main ();
 	} else
 		g_warning ("Can't find ui.xml");
 
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
 	fprintf (stderr, "\n\n--- Remove A ---\n\n\n");
-	bonobo_ui_component_rm (componenta, corba_container, "/", &ev);
+	bonobo_ui_component_rm (componenta, "/", &ev);
 
-	bonobo_ui_component_set (componentb, corba_container, "/status", statusa, &ev);
+	bonobo_ui_component_set (componentb, "/status", statusa, &ev);
 
-	bonobo_ui_component_set (componenta, corba_container, "/", simplea, &ev);
+	bonobo_ui_component_set (componenta, "/", simplea, &ev);
 
-	bonobo_ui_component_set (componentb, corba_container, "/",   toola, &ev);
+	bonobo_ui_component_set (componentb, "/",
+				 "<popups> <popup name=\"MyStuff\"/> </popups>", &ev);
+	bonobo_ui_component_set (componenta, "/popups/MyStuff", simpleb, &ev);
+
+	bonobo_ui_component_set (componentb, "/",   toola, &ev);
 
 	{
 		GtkWidget *widget = gtk_button_new_with_label ("My Label");
 		BonoboControl *control = bonobo_control_new (widget);
 		
 		gtk_widget_show (widget);
-		bonobo_ui_container_object_set (
-			corba_container,
+		bonobo_ui_component_object_set (
+			componenta,
 			"/menu/File/MyControl",
 			bonobo_object_corba_objref (BONOBO_OBJECT (control)),
 			NULL);
@@ -249,8 +286,8 @@ main (int argc, char **argv)
 		
 		gtk_entry_set_text (GTK_ENTRY (widget), "Example text");
 		gtk_widget_show (widget);
-		bonobo_ui_container_object_set (
-			corba_container,
+		bonobo_ui_component_object_set (
+			componenta,
 			"/toolbar/AControl",
 			bonobo_object_corba_objref (BONOBO_OBJECT (control)),
 			NULL);
@@ -258,24 +295,34 @@ main (int argc, char **argv)
 
 	bonobo_ui_component_add_listener (componentb, "MyFoo", toggled_cb, NULL);
 
-	bonobo_ui_component_set (componentb, corba_container, "/",     statusb, &ev);
+	bonobo_ui_component_set (componentb, "/",     statusb, &ev);
 
 	/* Duplicate set */
-	bonobo_ui_component_set (componenta, corba_container, "/", simplea, &ev);
+	bonobo_ui_component_set (componenta, "/", simplea, &ev);
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 
 	gtk_main ();
 
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
 	accel = bonobo_ui_util_build_accel (GDK_A, GDK_CONTROL_MASK, "KeyWibbleVerb");
-	bonobo_ui_component_set_tree (componenta, corba_container, "/keybindings", accel, &ev);
+	bonobo_ui_component_set_tree (componenta, "/keybindings", accel, &ev);
 	bonobo_ui_node_free (accel);
 
-	bonobo_ui_component_set (componentb, corba_container, "/menu", simpleb, &ev);
-	bonobo_ui_component_set (componenta, corba_container, "/",     toolb, &ev);
-	bonobo_ui_component_set (componenta, corba_container, "/menu/File/Nice", simplee, &ev);
+	bonobo_ui_component_set (componentb, "/menu", simpleb, &ev);
+	bonobo_ui_component_set (componenta, "/",     toolb, &ev);
+
+	/* A 'transparent' node merge */
+	txt = bonobo_ui_component_get_prop (componenta, "/toolbar", "look", NULL);
+	printf ("Before merge look '%s'\n", txt);
+	bonobo_ui_component_set (componenta, "/", "<dockitem name=\"toolbar\"/>", &ev);
+	txt = bonobo_ui_component_get_prop (componenta, "/toolbar", "look", NULL);
+	printf ("After merge look '%s'\n", txt);
+	if (txt == NULL || strcmp (txt, "icon"))
+		g_warning ("Serious transparency regression");
+
+	bonobo_ui_component_set (componenta, "/menu/File/Nice", simplee, &ev);
 
 	{
 		GtkWidget *widget = gtk_progress_bar_new ();
@@ -284,9 +331,8 @@ main (int argc, char **argv)
 
 		gtk_progress_bar_update (GTK_PROGRESS_BAR (widget), 0.5);
 		gtk_widget_show (widget);
-		bonobo_ui_container_object_set (
-			corba_container,
-			"/status/Progress",
+		bonobo_ui_component_object_set (
+			componenta, "/status/Progress",
 			bonobo_object_corba_objref (BONOBO_OBJECT (control)),
 			NULL);
 
@@ -295,38 +341,40 @@ main (int argc, char **argv)
 				    disconnect_progress, GUINT_TO_POINTER (id));
 	}
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
-	bonobo_ui_component_set (componentc, corba_container, "/commands",
+	bonobo_ui_component_set (componentc, "/commands",
 				 "<cmd name=\"MyFoo\" sensitive=\"0\"/>", &ev);
-	bonobo_ui_component_set (componentc, corba_container, "/menu", simplec, &ev);
+	bonobo_ui_component_set (componentc, "/menu", simplec, &ev);
 	
-	bonobo_ui_component_set (componentc, corba_container, "/menu/File", simpled, &ev);
+	bonobo_ui_component_set (componentc, "/menu/File", simpled, &ev);
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
 	fprintf (stderr, "\n\n--- Remove 2 ---\n\n\n");
-	bonobo_ui_component_rm (componentb, corba_container, "/", &ev);
+	bonobo_ui_component_rm (componentb, "/", &ev);
+	bonobo_ui_component_set_prop (componentc, "/menu/File/save",
+				      "label", "SaveC", NULL);
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
 	fprintf (stderr, "\n\n--- Remove 3 ---\n\n\n");
-	bonobo_ui_component_rm (componentc, corba_container, "/", &ev);
+	bonobo_ui_component_rm (componentc, "/", &ev);
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
-	bonobo_ui_container_freeze (corba_container, NULL);
+	bonobo_ui_component_freeze (componenta, NULL);
 
 	fprintf (stderr, "\n\n--- Remove 1 ---\n\n\n");
-	bonobo_ui_component_rm (componenta, corba_container, "/", &ev);
+	bonobo_ui_component_rm (componenta, "/", &ev);
 
-	bonobo_ui_container_thaw (corba_container, NULL);
+	bonobo_ui_component_thaw (componenta, NULL);
 	gtk_main ();
 
 	bonobo_object_unref (BONOBO_OBJECT (componenta));
@@ -334,7 +382,7 @@ main (int argc, char **argv)
 	bonobo_object_unref (BONOBO_OBJECT (componentc));
 
 	bonobo_object_unref (BONOBO_OBJECT (container));
-	gtk_widget_destroy (GTK_WIDGET (app));
+	gtk_widget_destroy (GTK_WIDGET (win));
 
 	CORBA_exception_free (&ev);
 
