@@ -15,6 +15,7 @@
 #undef PRINT_DEBUG
 
 static BonoboObjectClass *bonobo_print_parent_class;
+static BonoboPrintClass  *bonobo_print_class;
 
 POA_Bonobo_Print__vepv bonobo_print_vepv;
 
@@ -60,8 +61,12 @@ impl_render (PortableServer_Servant        _servant,
 
 	gnome_print_gsave (ctx);
 
-	print->render (ctx, pd->width, pd->height,
-		       scissor, print->user_data);
+	if (print->render)
+		print->render (ctx, pd->width, pd->height,
+			       scissor, print->user_data);
+	else
+		bonobo_print_class->render (ctx, pd->width, pd->height,
+					    scissor, print->user_data);
 
 	gnome_print_grestore (ctx);
 	gnome_print_context_close (ctx);
@@ -71,23 +76,13 @@ impl_render (PortableServer_Servant        _servant,
 	gnome_print_meta_access_buffer (meta_context,
 					&buffer, &buf_len);
 
+	/* FIXME: we could kill this copy by nailing gnome-print-meta.c */
 	data->_buffer = g_malloc (buf_len);
 	memcpy (data->_buffer, buffer, buf_len);
 	data->_length = buf_len;
 	data->_maximum = buf_len;
 
 	gtk_object_unref (GTK_OBJECT (meta_context));
-/*
-#ifdef PRINT_DEBUG
-	printf ("Sending data %d %d\n", data->_length, data->_maximum);
-	{
-		int i;
-		for (i = 0; i < data->_length; i++)
-			printf ("0x%x ", data->_buffer [i]);
-		printf ("\n");
-	}
-#endif
-*/
 
 	return data;
 }
@@ -119,6 +114,9 @@ static void
 bonobo_print_class_init (BonoboPrintClass *klass)
 {
 	bonobo_print_parent_class = gtk_type_class (bonobo_object_get_type ());
+	bonobo_print_class = klass;
+
+	klass->render = NULL;
 
 	init_print_corba_class ();
 }
@@ -126,7 +124,7 @@ bonobo_print_class_init (BonoboPrintClass *klass)
 /**
  * bonobo_print_get_type:
  *
- * Returns: the GtkType for a BonoboPrint.
+ * Returns: the GtkType for a BonoboPrint object.
  */
 GtkType
 bonobo_print_get_type (void)
@@ -151,8 +149,8 @@ bonobo_print_get_type (void)
 	return type;
 }
 
-static Bonobo_Print
-create_bonobo_print (BonoboObject *object)
+Bonobo_Print
+bonobo_print_corba_object_create (BonoboObject *object)
 {
 	POA_Bonobo_Print *servant;
 	CORBA_Environment ev;
@@ -174,19 +172,13 @@ create_bonobo_print (BonoboObject *object)
 }
 
 BonoboPrint *
-bonobo_print_new (BonoboPrintRenderFn *render,
-		  gpointer             user_data)
+bonobo_print_construct (BonoboPrint         *p,
+			Bonobo_Print         corba_p,
+			BonoboPrintRenderFn *render,
+			gpointer             user_data)
 {
-	BonoboPrint  *p;
-	Bonobo_Print  pr;
 	static gboolean warned = FALSE;
 
-	p = gtk_type_new (bonobo_print_get_type ());
-	g_return_val_if_fail (p != NULL, NULL);
-
-	pr = create_bonobo_print (BONOBO_OBJECT (p));
-	g_return_val_if_fail (pr != NULL, NULL);
-
 	if (!warned) {
 		g_warning ("The print interface is horribly immature, use at your own risk");
 		warned = TRUE;
@@ -195,9 +187,35 @@ bonobo_print_new (BonoboPrintRenderFn *render,
 	p->render       = render;
 	p->user_data    = user_data;
 	
-	bonobo_object_construct (BONOBO_OBJECT (p), pr);
-
-	return p;
+	return BONOBO_PRINT (
+		bonobo_object_construct (BONOBO_OBJECT (p), corba_p));
 }
 
+/**
+ * bonobo_print_new:
+ * @render: 
+ * @user_data: 
+ * 
+ * Create a new bonobo-print implementing BonoboObject
+ * interface.
+ * 
+ * Return value: 
+ **/
+BonoboPrint *
+bonobo_print_new (BonoboPrintRenderFn *render,
+		  gpointer             user_data)
+{
+	BonoboPrint  *p;
+	Bonobo_Print  corba_p;
 
+	p = gtk_type_new (bonobo_print_get_type ());
+	g_return_val_if_fail (p != NULL, NULL);
+
+	corba_p = bonobo_print_corba_object_create (BONOBO_OBJECT (p));
+	if (corba_p == CORBA_OBJECT_NIL){
+		bonobo_object_unref (BONOBO_OBJECT (p));
+		return NULL;
+	}
+
+	return bonobo_print_construct (p, corba_p, render, user_data);
+}
