@@ -22,6 +22,8 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 POA_Bonobo_UIComponent__vepv bonobo_ui_component_vepv;
 
+#define GET_CLASS(c) (BONOBO_UI_COMPONENT_CLASS (GTK_OBJECT (c)->klass))
+
 typedef struct {
 	char              *id;
 	BonoboUIListenerFn cb;
@@ -36,13 +38,11 @@ typedef struct {
 	GDestroyNotify destroy_fn;
 } UIVerb;
 
-/*
- * FIXME: should all be hashed for speed.
- */
 struct _BonoboUIComponentPrivate {
-	GHashTable *verbs;
-	GHashTable *listeners;
-	char       *name;
+	GHashTable        *verbs;
+	GHashTable        *listeners;
+	char              *name;
+	Bonobo_UIContainer container;
 };
 
 static inline BonoboUIComponent *
@@ -266,81 +266,6 @@ bonobo_ui_component_get_epv (void)
 	return epv;
 }
 
-static void
-bonobo_ui_component_class_init (BonoboUIComponentClass *klass)
-{
-	GtkObjectClass *object_class = (GtkObjectClass *) klass;
-	BonoboUIComponentClass *uclass = BONOBO_UI_COMPONENT_CLASS (klass);
-	
-	bonobo_ui_component_parent_class = gtk_type_class (BONOBO_OBJECT_TYPE);
-
-	object_class->destroy = bonobo_ui_component_destroy;
-
-	uclass->ui_event = ui_event;
-
-	bonobo_ui_component_vepv.Bonobo_Unknown_epv =
-		bonobo_object_get_epv ();
-	bonobo_ui_component_vepv.Bonobo_UIComponent_epv =
-		bonobo_ui_component_get_epv ();
-
-	signals [EXEC_VERB] = gtk_signal_new (
-		"exec_verb", GTK_RUN_FIRST,
-		object_class->type,
-		GTK_SIGNAL_OFFSET (BonoboUIComponentClass, exec_verb),
-		gtk_marshal_NONE__STRING,
-		GTK_TYPE_NONE, 1, GTK_TYPE_STRING);
-
-	signals [UI_EVENT] = gtk_signal_new (
-		"ui_event", GTK_RUN_FIRST,
-		object_class->type,
-		GTK_SIGNAL_OFFSET (BonoboUIComponentClass, ui_event),
-		gtk_marshal_NONE__POINTER_INT_POINTER,
-		GTK_TYPE_NONE, 3, GTK_TYPE_STRING, GTK_TYPE_INT,
-		GTK_TYPE_STRING);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
-}
-
-static void
-bonobo_ui_component_init (BonoboUIComponent *component)
-{
-	BonoboUIComponentPrivate *priv;
-
-	priv = g_new0 (BonoboUIComponentPrivate, 1);
-	priv->verbs = g_hash_table_new (g_str_hash, g_str_equal);
-	priv->listeners = g_hash_table_new (g_str_hash, g_str_equal);
-
-	component->priv = priv;
-}
-
-/**
- * bonobo_ui_component_get_type:
- *
- * Returns: the GtkType of the BonoboUIComponent class.
- */
-GtkType
-bonobo_ui_component_get_type (void)
-{
-	static GtkType type = 0;
-
-	if (!type) {
-		GtkTypeInfo info = {
-			"BonoboUIComponent",
-			sizeof (BonoboUIComponent),
-			sizeof (BonoboUIComponentClass),
-			(GtkClassInitFunc) bonobo_ui_component_class_init,
-			(GtkObjectInitFunc) bonobo_ui_component_init,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		type = gtk_type_unique (bonobo_object_get_type (), &info);
-	}
-
-	return type;
-}
-
 Bonobo_UIComponent
 bonobo_ui_component_corba_object_create (BonoboObject *object)
 {
@@ -401,19 +326,68 @@ bonobo_ui_component_new (const char *name)
 		component, corba_component, name));
 }
 
+BonoboUIComponent *
+bonobo_ui_component_new_default (void)
+{
+	char              *name;
+	BonoboUIComponent *component;
+
+	static int idx = 0;
+
+	name = g_strdup_printf (
+		"%s-%s-%d-%d",
+		gnome_app_id ? gnome_app_id : "unknown",
+		gnome_app_version ? gnome_app_version : "-.-",
+		getpid (), idx++);
+
+	component = bonobo_ui_component_new (name);
+	
+	g_free (name);
+
+	return component;
+}
+
+void
+bonobo_ui_component_set_name (BonoboUIComponent  *component,
+			      const char         *name)
+{
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	
+	g_free (component->priv->name);
+	component->priv->name = g_strdup (name);
+}
+
+const char *
+bonobo_ui_component_get_name (BonoboUIComponent  *component)
+{
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component), NULL);
+	
+	return component->priv->name;
+}
+
 void
 bonobo_ui_component_set (BonoboUIComponent  *component,
-			 Bonobo_UIContainer  container,
 			 const char         *path,
 			 const char         *xml,
 			 CORBA_Environment  *ev)
 {
-	CORBA_Environment *real_ev, tmp_ev;
-	Bonobo_UIComponent corba_component;
-	char *name;
+	GET_CLASS (component)->xml_set (component, path, xml, ev);
+}
 
+static void
+impl_xml_set (BonoboUIComponent  *component,
+	      const char         *path,
+	      const char         *xml,
+	      CORBA_Environment  *ev)
+{
+	CORBA_Environment *real_ev, tmp_ev;
+	Bonobo_UIContainer container;
+	char              *name;
+
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
-	g_return_if_fail (!component || BONOBO_IS_UI_COMPONENT (component));
 
 	if (ev)
 		real_ev = ev;
@@ -422,24 +396,7 @@ bonobo_ui_component_set (BonoboUIComponent  *component,
 		real_ev = &tmp_ev;
 	}
 
-	if (component)
-		name = component->priv->name;
-	else
-		name = "";
-
-	if (component != NULL)
-		corba_component = 
-			bonobo_object_corba_objref (BONOBO_OBJECT (component));
-	else
-		corba_component = CORBA_OBJECT_NIL;
-
-	Bonobo_UIContainer_register_component (
-		container, name,
-		corba_component, real_ev);
-
-	if (real_ev->_major != CORBA_NO_EXCEPTION && !ev)
-		g_warning ("Serious exception registering component '$%s'",
-			   bonobo_exception_get_text (real_ev));
+	name = component->priv->name ? component->priv->name : "";
 
 	Bonobo_UIContainer_node_set (container, path, xml,
 				     name, real_ev);
@@ -453,33 +410,44 @@ bonobo_ui_component_set (BonoboUIComponent  *component,
 }
 
 void
-bonobo_ui_component_set_tree (BonoboUIComponent  *component,
-			      Bonobo_UIContainer  container,
-			      const char         *path,
-			      BonoboUINode            *node,
-			      CORBA_Environment  *ev)
+bonobo_ui_component_set_tree (BonoboUIComponent *component,
+			      const char        *path,
+			      BonoboUINode      *node,
+			      CORBA_Environment *ev)
 {
 	char *str;
 
 	str = bonobo_ui_node_to_string (node, TRUE);	
 
-/*	fprintf (stderr, "Merging '%s'\n", mem);*/
+/*	fprintf (stderr, "Merging '%s'\n", str); */
 	
 	bonobo_ui_component_set (
-		component, container, path, str, ev);
+		component, path, str, ev);
 
 	bonobo_ui_node_free_string (str);
 }
 
 char *
-bonobo_ui_container_get (Bonobo_UIContainer  container,
-			 const char         *path,
-			 gboolean            recurse,
-			 CORBA_Environment  *ev)
+bonobo_ui_component_get (BonoboUIComponent *component,
+			 const char        *path,
+			 gboolean           recurse,
+			 CORBA_Environment *ev)
+{
+	return GET_CLASS (component)->xml_get (component, path, recurse, ev);
+}
+
+static char *
+impl_xml_get (BonoboUIComponent *component,
+	      const char        *path,
+	      gboolean           recurse,
+	      CORBA_Environment *ev)
 {
 	CORBA_Environment *real_ev, tmp_ev;
 	CORBA_char *xml;
+	Bonobo_UIContainer container;
 
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component), NULL);
+	container = component->priv->container;
 	g_return_val_if_fail (container != CORBA_OBJECT_NIL, NULL);
 
 	if (ev)
@@ -502,14 +470,16 @@ bonobo_ui_container_get (Bonobo_UIContainer  container,
 }
 
 BonoboUINode *
-bonobo_ui_container_get_tree (Bonobo_UIContainer  container,
+bonobo_ui_component_get_tree (BonoboUIComponent  *component,
 			      const char         *path,
 			      gboolean            recurse,
 			      CORBA_Environment  *ev)
 {	
-	char *xml = bonobo_ui_container_get (container, path, recurse, ev);
+	char *xml;
 	BonoboUINode *node;
 
+	xml = bonobo_ui_component_get (component, path, recurse, ev);
+
 	if (!xml)
 		return NULL;
 
@@ -518,22 +488,31 @@ bonobo_ui_container_get_tree (Bonobo_UIContainer  container,
 	if (!node)
 		return NULL;
 
-	bonobo_ui_xml_strip (node);
+	bonobo_ui_xml_strip (&node);
 
 	return node;
 }
 
 void
 bonobo_ui_component_rm (BonoboUIComponent  *component,
-			Bonobo_UIContainer  container,
 			const char         *path,
 			CORBA_Environment  *ev)
+{
+	GET_CLASS (component)->xml_rm (component, path, ev);
+}
+
+static void
+impl_xml_rm (BonoboUIComponent  *component,
+	     const char         *path,
+	     CORBA_Environment  *ev)
 {
 	BonoboUIComponentPrivate *priv;
 	CORBA_Environment *real_ev, tmp_ev;
+	Bonobo_UIContainer container;
 
-	g_return_if_fail (container != CORBA_OBJECT_NIL);
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
+	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
 	if (ev)
 		real_ev = ev;
@@ -551,28 +530,22 @@ bonobo_ui_component_rm (BonoboUIComponent  *component,
 		g_warning ("Serious exception removing path  '%s' '%s'",
 			   path, bonobo_exception_get_text (real_ev));
 
-	if (path [0] == '\0' || !strcmp (path, "/")) {
-		Bonobo_UIContainer_deregister_component (
-			container, priv->name, real_ev);
-		
-		if (!ev && real_ev->_major != CORBA_NO_EXCEPTION)
-			g_warning ("Serious exception removing path  '%s' '%s'",
-				   path, bonobo_exception_get_text (real_ev));
-	}
-
 	if (!ev)
 		CORBA_exception_free (&tmp_ev);
 }
 
 
 void
-bonobo_ui_container_object_set (Bonobo_UIContainer  container,
+bonobo_ui_component_object_set (BonoboUIComponent  *component,
 				const char         *path,
 				Bonobo_Unknown      control,
 				CORBA_Environment  *ev)
 {
 	CORBA_Environment *real_ev, tmp_ev;
+	Bonobo_UIContainer container;
 
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
 	if (ev)
@@ -593,13 +566,17 @@ bonobo_ui_container_object_set (Bonobo_UIContainer  container,
 }
 
 Bonobo_Unknown
-bonobo_ui_container_object_get (Bonobo_UIContainer  container,
+bonobo_ui_component_object_get (BonoboUIComponent  *component,
 				const char         *path,
 				CORBA_Environment  *ev)
 {
 	CORBA_Environment *real_ev, tmp_ev;
 	Bonobo_Unknown     ret;
+	Bonobo_UIContainer container;
 
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component),
+			      CORBA_OBJECT_NIL);
+	container = component->priv->container;
 	g_return_val_if_fail (container != CORBA_OBJECT_NIL,
 			      CORBA_OBJECT_NIL);
 
@@ -647,11 +624,21 @@ bonobo_ui_component_add_verb_list (BonoboUIComponent  *component,
 }
 
 void
-bonobo_ui_container_freeze (Bonobo_UIContainer  container,
-			    CORBA_Environment  *ev)
+bonobo_ui_component_freeze (BonoboUIComponent *component,
+			    CORBA_Environment *ev)
+{
+	GET_CLASS (component)->freeze (component, ev);
+}
+
+static void
+impl_freeze (BonoboUIComponent *component,
+	     CORBA_Environment *ev)
 {
 	CORBA_Environment *real_ev, tmp_ev;
+	Bonobo_UIContainer container;
 
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
 	if (ev)
@@ -672,11 +659,21 @@ bonobo_ui_container_freeze (Bonobo_UIContainer  container,
 }
 
 void
-bonobo_ui_container_thaw (Bonobo_UIContainer  container,
-			  CORBA_Environment  *ev)
+bonobo_ui_component_thaw (BonoboUIComponent *component,
+			  CORBA_Environment *ev)
+{
+	GET_CLASS (component)->thaw (component, ev);
+}
+
+static void
+impl_thaw (BonoboUIComponent *component,
+	   CORBA_Environment *ev)
 {
 	CORBA_Environment *real_ev, tmp_ev;
+	Bonobo_UIContainer container;
 
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
 	if (ev)
@@ -697,19 +694,32 @@ bonobo_ui_container_thaw (Bonobo_UIContainer  container,
 }
 
 void
-bonobo_ui_container_set_prop (Bonobo_UIContainer  container,
+bonobo_ui_component_set_prop (BonoboUIComponent  *component,
 			      const char         *path,
 			      const char         *prop,
 			      const char         *value,
 			      CORBA_Environment  *opt_ev)
+{
+	GET_CLASS (component)->set_prop (component, path, prop, value, opt_ev);
+}
+
+static void
+impl_set_prop (BonoboUIComponent  *component,
+	       const char         *path,
+	       const char         *prop,
+	       const char         *value,
+	       CORBA_Environment  *opt_ev)
 {
 	BonoboUINode *node;
 	char *parent_path;
+	Bonobo_UIContainer container;
 
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
 
-	node = bonobo_ui_container_get_tree (
-		container, path, FALSE, opt_ev);
+	node = bonobo_ui_component_get_tree (
+		component, path, FALSE, opt_ev);
 
 	g_return_if_fail (node != NULL);
 
@@ -718,8 +728,7 @@ bonobo_ui_container_set_prop (Bonobo_UIContainer  container,
 	parent_path = bonobo_ui_xml_get_parent_path (path);
 
 	bonobo_ui_component_set_tree (
-		NULL, container,
-		parent_path, node, opt_ev);
+		component, parent_path, node, opt_ev);
 
 	g_free (parent_path);
 
@@ -727,19 +736,28 @@ bonobo_ui_container_set_prop (Bonobo_UIContainer  container,
 }
 
 gchar *
-bonobo_ui_container_get_prop (Bonobo_UIContainer  container,
-			      const char         *path,
-			      const char         *prop,
-			      CORBA_Environment  *opt_ev)
+bonobo_ui_component_get_prop (BonoboUIComponent *component,
+			      const char        *path,
+			      const char        *prop,
+			      CORBA_Environment *opt_ev)
+{
+	return GET_CLASS (component)->get_prop (component, path, prop, opt_ev);
+}
+
+static gchar *
+impl_get_prop (BonoboUIComponent *component,
+	       const char        *path,
+	       const char        *prop,
+	       CORBA_Environment *opt_ev)
 {
 	BonoboUINode *node;
 	xmlChar *ans;
 	gchar   *ret;
 
-	g_return_val_if_fail (container != CORBA_OBJECT_NIL, NULL);
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component), NULL);
 
-	node = bonobo_ui_container_get_tree (
-		container, path, FALSE, opt_ev);
+	node = bonobo_ui_component_get_tree (
+		component, path, FALSE, opt_ev);
 
 	g_return_val_if_fail (node != NULL, NULL);
 
@@ -755,29 +773,25 @@ bonobo_ui_container_get_prop (Bonobo_UIContainer  container,
 	return ret;
 }
 
-void
-bonobo_ui_container_set_status (Bonobo_UIContainer  container,
-				const char         *text,
-				CORBA_Environment  *opt_ev)
+gboolean
+bonobo_ui_component_path_exists (BonoboUIComponent *component,
+				 const char        *path,
+				 CORBA_Environment *ev)
 {
-	char *str;
-
-	g_return_if_fail (text != NULL);
-	g_return_if_fail (container != CORBA_OBJECT_NIL);
-
-	str = g_strdup_printf ("<item name=\"main\">%s</item>", text);
-
-	bonobo_ui_component_set (NULL, container, "/status", str, opt_ev);
+	return GET_CLASS (component)->exists (component, path, ev);
 }
 
-gboolean
-bonobo_ui_container_path_exists (Bonobo_UIContainer  container,
-				 const char         *path,
-				 CORBA_Environment  *ev)
+static gboolean
+impl_exists (BonoboUIComponent *component,
+	     const char        *path,
+	     CORBA_Environment *ev)
 {
 	gboolean ret;
+	Bonobo_UIContainer container;
 	CORBA_Environment *real_ev, tmp_ev;
 
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component), FALSE);
+	container = component->priv->container;
 	g_return_val_if_fail (container != CORBA_OBJECT_NIL, FALSE);
 
 	if (ev)
@@ -801,3 +815,182 @@ bonobo_ui_container_path_exists (Bonobo_UIContainer  container,
 
 	return ret;
 }
+
+void
+bonobo_ui_component_set_status (BonoboUIComponent *component,
+				const char        *text,
+				CORBA_Environment *opt_ev)
+{
+	char *str;
+
+	g_return_if_fail (text != NULL);
+
+	str = g_strdup_printf ("<item name=\"main\">%s</item>", text);
+
+	bonobo_ui_component_set (component, "/status", str, opt_ev);
+}
+
+void
+bonobo_ui_component_unset_container (BonoboUIComponent *component)
+{
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+
+	if (component->priv->container != CORBA_OBJECT_NIL) {
+		CORBA_Environment  ev;
+		char              *name;
+
+		bonobo_ui_component_rm (component, "/", NULL);
+
+		CORBA_exception_init (&ev);
+
+		name = component->priv->name ? component->priv->name : "";
+
+		Bonobo_UIContainer_deregister_component (
+			component->priv->container, name, &ev);
+		
+		if (ev._major != CORBA_NO_EXCEPTION)
+			g_warning ("Serious exception deregistering component '%s'",
+				   bonobo_exception_get_text (&ev));
+
+		CORBA_exception_free (&ev);
+
+		bonobo_object_release_unref (component->priv->container, NULL);
+	}
+
+	component->priv->container = CORBA_OBJECT_NIL;
+}
+
+void
+bonobo_ui_component_set_container (BonoboUIComponent *component,
+				   Bonobo_UIContainer container)
+{
+	Bonobo_UIContainer ref_cont;
+
+	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
+
+	if (container != CORBA_OBJECT_NIL) {
+		Bonobo_UIComponent corba_component;
+		char              *name;
+		CORBA_Environment  ev;
+
+		ref_cont = 		
+			bonobo_object_dup_ref (container, NULL);
+
+		CORBA_exception_init (&ev);
+
+		corba_component = 
+			bonobo_object_corba_objref (BONOBO_OBJECT (component));
+
+		name = component->priv->name ? component->priv->name : "";
+
+		Bonobo_UIContainer_register_component (
+			ref_cont, name, corba_component, &ev);
+
+		if (ev._major != CORBA_NO_EXCEPTION)
+			g_warning ("Serious exception registering component '$%s'",
+				   bonobo_exception_get_text (&ev));
+		
+		CORBA_exception_free (&ev);
+	} else
+		ref_cont = CORBA_OBJECT_NIL;
+
+	bonobo_ui_component_unset_container (component);
+
+	component->priv->container = ref_cont;
+}
+
+Bonobo_UIContainer
+bonobo_ui_component_get_container (BonoboUIComponent *component)
+{
+	g_return_val_if_fail (BONOBO_IS_UI_COMPONENT (component),
+			      CORBA_OBJECT_NIL);
+	
+	return component->priv->container;
+}
+
+static void
+bonobo_ui_component_class_init (BonoboUIComponentClass *klass)
+{
+	GtkObjectClass *object_class = (GtkObjectClass *) klass;
+	BonoboUIComponentClass *uclass = BONOBO_UI_COMPONENT_CLASS (klass);
+	
+	bonobo_ui_component_parent_class = gtk_type_class (BONOBO_OBJECT_TYPE);
+
+	object_class->destroy = bonobo_ui_component_destroy;
+
+	uclass->ui_event = ui_event;
+
+	bonobo_ui_component_vepv.Bonobo_Unknown_epv =
+		bonobo_object_get_epv ();
+	bonobo_ui_component_vepv.Bonobo_UIComponent_epv =
+		bonobo_ui_component_get_epv ();
+
+	signals [EXEC_VERB] = gtk_signal_new (
+		"exec_verb", GTK_RUN_FIRST,
+		object_class->type,
+		GTK_SIGNAL_OFFSET (BonoboUIComponentClass, exec_verb),
+		gtk_marshal_NONE__STRING,
+		GTK_TYPE_NONE, 1, GTK_TYPE_STRING);
+
+	signals [UI_EVENT] = gtk_signal_new (
+		"ui_event", GTK_RUN_FIRST,
+		object_class->type,
+		GTK_SIGNAL_OFFSET (BonoboUIComponentClass, ui_event),
+		gtk_marshal_NONE__POINTER_INT_POINTER,
+		GTK_TYPE_NONE, 3, GTK_TYPE_STRING, GTK_TYPE_INT,
+		GTK_TYPE_STRING);
+
+	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+
+	uclass->freeze   = impl_freeze;
+	uclass->thaw     = impl_thaw;
+	uclass->xml_set  = impl_xml_set;
+	uclass->xml_get  = impl_xml_get;
+	uclass->xml_rm   = impl_xml_rm;
+	uclass->set_prop = impl_set_prop;
+	uclass->get_prop = impl_get_prop;
+	uclass->exists   = impl_exists;
+
+}
+
+static void
+bonobo_ui_component_init (BonoboUIComponent *component)
+{
+	BonoboUIComponentPrivate *priv;
+
+	priv = g_new0 (BonoboUIComponentPrivate, 1);
+	priv->verbs = g_hash_table_new (g_str_hash, g_str_equal);
+	priv->listeners = g_hash_table_new (g_str_hash, g_str_equal);
+	priv->container = CORBA_OBJECT_NIL;
+
+	component->priv = priv;
+}
+
+/**
+ * bonobo_ui_component_get_type:
+ *
+ * Returns: the GtkType of the BonoboUIComponent class.
+ */
+GtkType
+bonobo_ui_component_get_type (void)
+{
+	static GtkType type = 0;
+
+	if (!type) {
+		GtkTypeInfo info = {
+			"BonoboUIComponent",
+			sizeof (BonoboUIComponent),
+			sizeof (BonoboUIComponentClass),
+			(GtkClassInitFunc) bonobo_ui_component_class_init,
+			(GtkObjectInitFunc) bonobo_ui_component_init,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		type = gtk_type_unique (bonobo_object_get_type (), &info);
+	}
+
+	return type;
+}
+
