@@ -319,6 +319,9 @@ get_stock_pixbuf (const char *name)
 	GdkPixbuf *pixbuf;
 	char *path;
 
+	if (!name)
+		return NULL;
+
 	entry = gnome_stock_pixmap_checkfor (name, GNOME_STOCK_PIXMAP_REGULAR);
 	if (entry == NULL)
 		return NULL;
@@ -351,28 +354,41 @@ get_stock_pixbuf (const char *name)
 }
 
 GdkPixbuf *
-bonobo_ui_util_xml_get_icon_pixbuf (BonoboUINode *node)
+bonobo_ui_util_xml_get_icon_pixbuf (BonoboUINode *node, gboolean prepend_menu)
 {
 	GdkPixbuf *icon_pixbuf = NULL;
-	char      *type;
+	char      *type, *text;
 
 	g_return_val_if_fail (node != NULL, NULL);
 
 	if (!(type = bonobo_ui_node_get_attr (node, "pixtype")))
 		return NULL;
 
+	if (!(text = bonobo_ui_node_get_attr (node, "pixname"))) {
+		bonobo_ui_node_free_string (type);
+		return NULL;
+	}
+
+	if (!text)
+		return NULL;
+
 	if (!strcmp (type, "stock")) {
-		char      *text;
 
-		text = bonobo_ui_node_get_attr (node, "pixname");
-		icon_pixbuf = get_stock_pixbuf (text);
-		bonobo_ui_node_free_string (text);
+		if (prepend_menu) {
+			char *fullname = g_strconcat ("Menu_", text, NULL);
+			icon_pixbuf = get_stock_pixbuf (fullname);
+			g_free (fullname);
+		} else
+			icon_pixbuf = get_stock_pixbuf (text);
+
 	} else if (!strcmp (type, "filename")) {
-		char *name, *text;
+		char *name;
 
-		text = bonobo_ui_node_get_attr (node, "pixname");
-		name = gnome_pixmap_file (text);
-		bonobo_ui_node_free_string (text);
+		if (text [0] == '/' && g_file_exists (text)) {
+			name = g_strdup (text);
+		} else {
+			name = gnome_pixmap_file (text);
+		}
 
 		if (name == NULL)
 			g_warning ("Could not find GNOME pixmap file %s", text);
@@ -380,36 +396,31 @@ bonobo_ui_util_xml_get_icon_pixbuf (BonoboUINode *node)
 			icon_pixbuf = gdk_pixbuf_new_from_file (name);
 
 		g_free (name);
+
 	} else if (!strcmp (type, "pixbuf")) {
-		char      *text;
-
-		text = bonobo_ui_node_get_attr (node, "pixname");
-
-		g_return_val_if_fail (text != NULL, NULL);
 		
 		/* Get pointer to GdkPixbuf */
 		icon_pixbuf = bonobo_ui_util_xml_to_pixbuf (text);
-		bonobo_ui_node_free_string (text);
 
 		g_return_val_if_fail (icon_pixbuf != NULL, NULL);
-	} else {
+	} else
 		g_warning ("Unknown icon_pixbuf type '%s'", type);
-	}
 
+	bonobo_ui_node_free_string (text);
 	bonobo_ui_node_free_string (type);
 
 	return icon_pixbuf;
 }
 
 GtkWidget *
-bonobo_ui_util_xml_get_icon_pixmap_widget (BonoboUINode *node)
+bonobo_ui_util_xml_get_icon_pixmap_widget (BonoboUINode *node, gboolean prepend_menu)
 {
 	GnomePixmap *gpixmap;
 	GdkPixbuf *pixbuf;
 
 	g_return_val_if_fail (node != NULL, NULL);
 
-	pixbuf = bonobo_ui_util_xml_get_icon_pixbuf (node);
+	pixbuf = bonobo_ui_util_xml_get_icon_pixbuf (node, prepend_menu);
 	if (pixbuf == NULL)
 		return NULL;
 	
@@ -454,8 +465,8 @@ bonobo_ui_util_xml_set_pix_xpm (BonoboUINode     *node,
 }
 				     
 void
-bonobo_ui_util_xml_set_pix_stock (BonoboUINode     *node,
-				  const char  *name)
+bonobo_ui_util_xml_set_pix_stock (BonoboUINode *node,
+				  const char   *name)
 {
 	g_return_if_fail (node != NULL);
 	g_return_if_fail (name != NULL);
@@ -465,8 +476,8 @@ bonobo_ui_util_xml_set_pix_stock (BonoboUINode     *node,
 }
 
 void
-bonobo_ui_util_xml_set_pix_fname (BonoboUINode     *node,
-				  const char  *name)
+bonobo_ui_util_xml_set_pix_fname (BonoboUINode *node,
+				  const char   *name)
 {
 	g_return_if_fail (node != NULL);
 	g_return_if_fail (name != NULL);
@@ -651,7 +662,7 @@ BonoboUINode *
 bonobo_ui_util_new_menu (gboolean    submenu,
 			 const char *name,
 			 const char *label,
-			 const char *descr,
+			 const char *tip,
 			 const char *verb)
 {
 	BonoboUINode *node;
@@ -667,8 +678,8 @@ bonobo_ui_util_new_menu (gboolean    submenu,
 	if (label)
 		bonobo_ui_node_set_attr (node, "label", label);
 
-	if (descr)
-		bonobo_ui_node_set_attr (node, "descr", descr);
+	if (tip)
+		bonobo_ui_node_set_attr (node, "tip", tip);
 
 	if (verb)
 		bonobo_ui_node_set_attr (node, "verb", verb);
@@ -726,7 +737,7 @@ bonobo_ui_util_set_toggle (BonoboUINode    *node,
 BonoboUINode *
 bonobo_ui_util_new_std_toolbar (const char *name,
 				const char *label,
-				const char *descr,
+				const char *tip,
 				const char *verb)
 {
 	BonoboUINode *node;
@@ -734,13 +745,12 @@ bonobo_ui_util_new_std_toolbar (const char *name,
 	g_return_val_if_fail (name != NULL, NULL);
 	
 	node = bonobo_ui_node_new ("toolitem");
-	bonobo_ui_node_set_attr (node, "type", "std");
 	bonobo_ui_node_set_attr (node, "name", name);
 	
 	if (label)
 		bonobo_ui_node_set_attr (node, "label", label);
-	if (descr)
-		bonobo_ui_node_set_attr (node, "descr", descr);
+	if (tip)
+		bonobo_ui_node_set_attr (node, "tip", tip);
 	if (verb)
 		bonobo_ui_node_set_attr (node, "verb", verb);
 
@@ -750,7 +760,7 @@ bonobo_ui_util_new_std_toolbar (const char *name,
 BonoboUINode *
 bonobo_ui_util_new_toggle_toolbar (const char *name,
 				   const char *label,
-				   const char *descr,
+				   const char *tip,
 				   const char *id)
 {
 	BonoboUINode *node;
@@ -763,8 +773,8 @@ bonobo_ui_util_new_toggle_toolbar (const char *name,
 	
 	if (label)
 		bonobo_ui_node_set_attr (node, "label", label);
-	if (descr)
-		bonobo_ui_node_set_attr (node, "descr", descr);
+	if (tip)
+		bonobo_ui_node_set_attr (node, "tip", tip);
 	if (id)
 		bonobo_ui_node_set_attr (node, "id", id);
 
@@ -840,12 +850,20 @@ void
 bonobo_ui_util_translate_ui (BonoboUINode *bnode)
 {
         BonoboUINode *l;
-        xmlNode *node = XML_NODE (bnode);
+        xmlNode *node;
 	xmlAttr *prop, *old_props;
 
-	if (!node)
+	if (!bnode)
 		return;
 
+	bonobo_ui_xml_strip (&bnode);
+	if (!bnode) {
+		g_warning ("All xml stripped away");
+		return;
+	}
+
+	node = XML_NODE (bnode);
+
 	old_props = node->properties;
 	node->properties = NULL;
 
@@ -918,11 +936,12 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
 {
 	BonoboUINode *node;
 
+	g_return_val_if_fail (app_name != NULL, NULL);
 	g_return_val_if_fail (file_name != NULL, NULL);
 
         node = bonobo_ui_node_from_file (file_name);
-        
-	bonobo_ui_xml_strip (node);
+
+	bonobo_ui_xml_strip (&node);
 
 	bonobo_ui_util_translate_ui (node);
 
@@ -933,13 +952,18 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
 
 void
 bonobo_ui_util_set_ui (BonoboUIComponent *component,
-		       Bonobo_UIContainer container,
 		       const char        *app_prefix,
 		       const char        *file_name,
 		       const char        *app_name)
 {
 	char *fname;
 	BonoboUINode *ui;
+
+	if (bonobo_ui_component_get_container (component) == CORBA_OBJECT_NIL) {
+		g_warning ("Component must be associated with a container first "
+			   "see bonobo_component_set_container");
+		return;
+	}
 	
 	fname = bonobo_ui_util_get_ui_fname (app_prefix, file_name);
 	if (!fname) {
@@ -951,7 +975,7 @@ bonobo_ui_util_set_ui (BonoboUIComponent *component,
 	
 	if (ui)
 		bonobo_ui_component_set_tree (
-			component, container, "/", ui, NULL);
+			component, "/", ui, NULL);
 	
 	g_free (fname);
 	bonobo_ui_node_free (ui);
@@ -1286,21 +1310,21 @@ bonobo_ui_util_accel_name (guint              accelerator_key,
 }
 
 void
-bonobo_ui_util_set_pixbuf (Bonobo_UIContainer container,
+bonobo_ui_util_set_pixbuf (BonoboUIComponent *component,
 			   const char        *path,
 			   GdkPixbuf         *pixbuf)
 {
 	char *parent_path;
 	BonoboUINode *node;
 
-	node = bonobo_ui_container_get_tree (container, path, FALSE, NULL);
+	node = bonobo_ui_component_get_tree (component, path, FALSE, NULL);
 
 	g_return_if_fail (node != NULL);
 
 	bonobo_ui_util_xml_set_pixbuf (node, pixbuf);
 
 	parent_path = bonobo_ui_xml_get_parent_path (path);
-	bonobo_ui_component_set_tree (NULL, container, parent_path, node, NULL);
+	bonobo_ui_component_set_tree (component, parent_path, node, NULL);
 
 	bonobo_ui_node_free (node);
 
