@@ -10,6 +10,7 @@
 
 #include "config.h"
 #include <string.h>
+#include <gtk/gtksignal.h>
 #include <bonobo/bonobo-ui-xml.h>
 
 #include <gnome-xml/tree.h>
@@ -57,43 +58,83 @@ identical (BonoboUIXml *tree, gpointer a, gpointer b)
 	return val;
 }
 
-/* XML_NODE cast hack again used here since BonoboUINode doesn't expose
- * property iterators
+/*
+ * XML_NODE cast hack again used here since BonoboUINode
+ * doesn't expose property iterators
  */
-static void
-do_strip (BonoboUINode *bnode)
+static gboolean
+do_strip (xmlNode *node)
 {
-        BonoboUINode *l, *next;
-	xmlAttr *a;
-        xmlNode *node = XML_NODE (bnode);
+        xmlNode *l, *next;
+	gboolean suspicious = FALSE;
 
 	if (!node)
-		return;
+		return FALSE;
 
-	if (node->type == XML_COMMENT_NODE) {
+	switch (node->type) {
+        case XML_DOCUMENT_FRAG_NODE:
+        case XML_ELEMENT_NODE:
+	case XML_TEXT_NODE:
+        case XML_ENTITY_NODE:
+        case XML_ENTITY_REF_NODE: {
+		xmlAttr *a, *nexta;
+
+		node->nsDef = NULL;
+		node->ns = NULL;
+		node->doc = NULL;
+
+		for (a = node->properties; a; a = nexta) {
+			nexta = a->next;
+			a->ns = NULL;
+			do_strip (a->val);
+		}
+
+		for (l = node->childs; l; l = next) {
+			next = l->next;
+			do_strip (l);
+		}
+		break;
+	}
+
+	case XML_ATTRIBUTE_NODE: {
+		xmlAttr *attr = (xmlAttr *)node;
+		attr->ns = NULL;
+		do_strip (attr->val);
+		break;
+	}
+
+        case XML_PI_NODE:
+        case XML_COMMENT_NODE:
+        case XML_DOCUMENT_NODE:
+        case XML_HTML_DOCUMENT_NODE:
+        case XML_DOCUMENT_TYPE_NODE:
+        case XML_NOTATION_NODE:
+        case XML_CDATA_SECTION_NODE:
+		suspicious = TRUE;
+		break;
+	}
+
+	if (suspicious) {
+/*		g_warning ("node looks suspicious %d: '%s'",
+			   node->type,
+			   bonobo_ui_node_to_string (BNODE (node), TRUE));*/
 		xmlUnlinkNode (node);
 		bonobo_ui_node_free (BNODE (node));
-		return;
-	}
-
-	node->ns = NULL;
-	node->doc = NULL;
-	node->nsDef = NULL;
-
-	for (a = node->properties; a; a = a->next)
-		a->ns = NULL;
-
-	for (l = bonobo_ui_node_children (bnode); l; l = next) {
-		next = bonobo_ui_node_next (l);
-		do_strip (l);
-	}
+		return TRUE;
+	} else
+		return FALSE;
 }
 
 void
-bonobo_ui_xml_strip (BonoboUINode *node)
+bonobo_ui_xml_strip (BonoboUINode **node)
 {
-	for (; node; node = bonobo_ui_node_next (node))
-		do_strip (node);
+	BonoboUINode *next, *l;
+
+	for (l = *node; l; l = next) {
+		next = bonobo_ui_node_next (l);
+		if (l == *node && do_strip (XML_NODE (l)))
+			*node = next;
+	}
 }
 
 gpointer
@@ -124,9 +165,28 @@ bonobo_ui_xml_clean (BonoboUIXml  *tree,
 		bonobo_ui_xml_clean (tree, l);
 }
 
+static void
+set_children_dirty (BonoboUIXml *tree, BonoboUINode *node)
+{
+	BonoboUINode *l;
+
+	if (!node)
+		return;
+
+	for (l = bonobo_ui_node_children (node); l;
+	     l = bonobo_ui_node_next (l)) {
+		BonoboUIXmlData *data;
+
+		data = bonobo_ui_xml_get_data (tree, l);
+		data->dirty = TRUE;
+		
+		set_children_dirty (tree, l);
+	}
+}
+
 /*
- * FIXME: this functionality is broken and should live in bonobo-win.c
- * for cleanliness and never in this more generic code.
+ * FIXME: the placeholder functionality is broken and should live in
+ * bonobo-win.c for cleanliness and never in this more generic code.
  */
 void
 bonobo_ui_xml_set_dirty (BonoboUIXml *tree, BonoboUINode *node)
@@ -146,6 +206,9 @@ bonobo_ui_xml_set_dirty (BonoboUIXml *tree, BonoboUINode *node)
 
 		l = bonobo_ui_node_parent (l);
 	}
+
+	/* Too conservative in some cases.*/
+	set_children_dirty (tree, node);
 }
 
 char *
@@ -338,6 +401,29 @@ move_children (BonoboUINode *from, BonoboUINode *to)
 	g_assert (bonobo_ui_node_children (from) == NULL);
 }
 
+static void
+prune_overrides_by_id (BonoboUIXml *tree, BonoboUIXmlData *data, gpointer id)
+{
+	GSList *l, *next;
+
+	g_return_if_fail (id != NULL);
+	
+	for (l = data->overridden; l; l = next) {
+		BonoboUIXmlData *o_data;
+				
+		next = l->next;
+		o_data = bonobo_ui_xml_get_data (tree, l->data);
+
+		if (identical (tree, o_data->id, id)) {
+			node_free (tree, l->data);
+
+			data->overridden =
+				g_slist_remove_link (data->overridden, l);
+			g_slist_free_1 (l);
+		}
+	}
+}
+
 static void merge (BonoboUIXml *tree, BonoboUINode *current, BonoboUINode **new);
 
 static void
@@ -345,7 +431,10 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 {
 	BonoboUIXmlData *data = bonobo_ui_xml_get_data (tree, new);
 	BonoboUIXmlData *old_data = bonobo_ui_xml_get_data (tree, old);
-	gboolean         same;
+	gboolean         same, transparent;
+
+	/* Is it just a path / grouping simplifying entry with no content ? */
+	transparent = bonobo_ui_node_transparent (new);
 
 	same = identical (tree, data->id, old_data->id);
 
@@ -355,11 +444,14 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 	if (!same) {
 		gtk_signal_emit (GTK_OBJECT (tree), signals [OVERRIDE], old);
 
+		prune_overrides_by_id (tree, data, data->id);
 		data->overridden = g_slist_prepend (old_data->overridden, old);
+		
 	} else {
 		data->id = old_data->id;
 		data->overridden = old_data->overridden;
 		gtk_signal_emit (GTK_OBJECT (tree), signals [REPLACE_OVERRIDE], new, old);
+
 /*		fprintf (stderr, "Replace override of '%s' '%s' with '%s' '%s'",
 			 old->name, bonobo_ui_node_get_attr (old, "name"),
 			 new->name, bonobo_ui_node_get-attr (new, "name"));*/
@@ -378,14 +470,8 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 
 	g_assert (bonobo_ui_node_children (old) == NULL);
 
-	/*
-	 *   A path simplifying entry: FIXME ignore just a name too
-	 * and hook into 'Same' code.
-	 */
-	if (!XML_NODE (new)->properties)
-		XML_NODE (new)->properties =
-			xmlCopyPropList (XML_NODE (new),
-					 XML_NODE (old)->properties);
+	if (transparent)
+		bonobo_ui_node_copy_attrs (old, new);
 
 	bonobo_ui_xml_set_dirty (tree, new);
 
@@ -435,18 +521,22 @@ reinstate_old_node (BonoboUIXml *tree, BonoboUINode *node)
 		BonoboUIXmlData *child_data = 
 			bonobo_ui_xml_get_data (tree, bonobo_ui_node_children (node));
 		data->id = child_data->id;
-		return;
-	} else {
-/*		fprintf (stderr, "destroying node '%s' '%s'\n",
-		node->name, bonobo_ui_node_get_attr (node, "name"));*/
 
 		/* Mark dirty */
 		bonobo_ui_xml_set_dirty (tree, node);
-
-		gtk_signal_emit (GTK_OBJECT (tree), signals [REMOVE], node);
-		bonobo_ui_node_unlink (node);
+		
+		gtk_signal_emit (GTK_OBJECT (tree), signals [REINSTATE], node);
+		return;
 	}
-
+/*		fprintf (stderr, "destroying node '%s' '%s'\n",
+		node->name, bonobo_ui_node_get_attr (node, "name"));*/
+		
+	/* Mark dirty */
+	bonobo_ui_xml_set_dirty (tree, node);
+	
+	gtk_signal_emit (GTK_OBJECT (tree), signals [REMOVE], node);
+	bonobo_ui_node_unlink (node);
+	
 	if (node == tree->root) /* Ugly special case */
 		tree->root = NULL;
 
@@ -675,6 +765,9 @@ bonobo_ui_xml_make_path  (BonoboUINode *node)
 			g_string_prepend (path, tmp);
 			g_string_prepend (path, "/");
 			bonobo_ui_node_free_string (tmp);
+		} else {
+			g_string_prepend (path, bonobo_ui_node_get_name (node));
+			g_string_prepend (path, "/");
 		}
 
 		node = bonobo_ui_node_parent (node);
@@ -687,29 +780,6 @@ bonobo_ui_xml_make_path  (BonoboUINode *node)
 	return tmp;
 }
 
-static void
-prune_overrides_by_id (BonoboUIXml *tree, BonoboUIXmlData *data, gpointer id)
-{
-	GSList *l, *next;
-
-	g_return_if_fail (id != NULL);
-	
-	for (l = data->overridden; l; l = next) {
-		BonoboUIXmlData *o_data;
-				
-		next = l->next;
-		o_data = bonobo_ui_xml_get_data (tree, l->data);
-
-		if (identical (tree, o_data->id, id)) {
-			node_free (tree, l->data);
-
-			data->overridden =
-				g_slist_remove_link (data->overridden, l);
-			g_slist_free_1 (l);
-		}
-	}
-}
-
 static void
 reinstate_node (BonoboUIXml *tree, BonoboUINode *node,
 		gpointer id, gboolean nail_me)
@@ -769,8 +839,8 @@ merge (BonoboUIXml *tree, BonoboUINode *current, BonoboUINode **new)
 			b_name = bonobo_ui_node_get_attr (b, "name");
 
 			if (!a_name && !b_name &&
-                            bonobo_ui_node_has_name (a,
-                                                     bonobo_ui_node_get_name (b)))
+                            bonobo_ui_node_has_name (
+				    a, bonobo_ui_node_get_name (b)))
 				break;
 
 			if (!a_name || !b_name)
@@ -818,10 +888,10 @@ merge (BonoboUIXml *tree, BonoboUINode *current, BonoboUINode **new)
 }
 
 BonoboUIXmlError
-bonobo_ui_xml_merge (BonoboUIXml *tree,
-		     const char  *path,
-		     BonoboUINode     *nodes,
-		     gpointer     id)
+bonobo_ui_xml_merge (BonoboUIXml  *tree,
+		     const char   *path,
+		     BonoboUINode *nodes,
+		     gpointer      id)
 {
 	BonoboUINode *current;
 
@@ -830,7 +900,7 @@ bonobo_ui_xml_merge (BonoboUIXml *tree,
 	if (nodes == NULL)
 		return BONOBO_UI_XML_OK;
 
-	bonobo_ui_xml_strip (nodes);
+	bonobo_ui_xml_strip (&nodes);
 	set_id (tree, nodes, id);
 
 	current = bonobo_ui_xml_get_path (tree, path);
