@@ -243,15 +243,6 @@ load_game_ui_cb (BonoboUIHandler *uih, void *user_data,
 	g_warning ("As yet, unimplemented; need to create a stream");
 }
 
-static void
-view_new_game_cb (BonoboView *view, const char *verb_name, void *user_data)
-{
-	view_data_t *view_data = (view_data_t *) user_data;
-
-	minefield_restart (view_data->embeddable_data->data);
-	embeddable_update_all_views (view_data->embeddable_data);
-}
-
 /*
  * When one of our views is activated, we merge our menus
  * in with our container's menus.
@@ -519,11 +510,6 @@ view_factory (BonoboEmbeddable *embeddable,
 	view_data->view = view;
 	gtk_object_set_data (GTK_OBJECT (view), "view_data", view_data);
 
-	/*
-	 * Register callbacks to handle the verbs
-	 */
-	bonobo_view_register_verb (view, "NewGame", view_new_game_cb, view_data);
-
 	/*
 	 * When our container wants to activate a given view of this
 	 * component, we will get the "activate" signal.
@@ -593,29 +579,6 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	minefield_set_mines (embeddable_data->data, 40);
 	minefield_restart   (embeddable_data->data);
 
-	/*
-	 * Add some verbs to the embeddable.
-	 *
-	 * Verbs are simple non-paramameterized actions which the
-	 * component can perform.  The BonoboEmbeddable must maintain a
-	 * list of the verbs which a component supports, and the
-	 * component author must register callbacks for each of his
-	 * verbs with the BonoboView.
-	 *
-	 * The container application will then have the programmatic
-	 * ability to execute the verbs on the component.  It will
-	 * also provide a simple mechanism whereby the user can
-	 * right-click on the component to create a popup menu
-	 * listing the available verbs.
-	 *
-	 * We provide one simple verb whose job it is to clear the
-	 * window.
-	 */
-	bonobo_embeddable_add_verb (embeddable,
-				   "NewGame",
-				   _("_New Game"),
-				   _("Start a new game"));
-
 	/*
 	 * Count the new running object
 	 */
