@@ -104,41 +104,36 @@ static int
 stream_read (Bonobo_Stream stream, embeddable_data_t *embeddable_data)
 {
 	Bonobo_Stream_iobuf *buffer;
-	CORBA_long bytes_read;
-	CORBA_Environment ev;
-
-	buffer = Bonobo_Stream_iobuf__alloc ();
+	CORBA_Environment    ev;
 
 	CORBA_exception_init (&ev);
 	do {
-
 #define READ_CHUNK_SIZE 65536
-		bytes_read = Bonobo_Stream_read (stream, READ_CHUNK_SIZE,
-						&buffer, &ev);
+		Bonobo_Stream_read (stream, READ_CHUNK_SIZE,
+				    &buffer, &ev);
 
 		if (ev._major != CORBA_NO_EXCEPTION) {
-			CORBA_free (buffer);
 			CORBA_exception_free (&ev);
 			return -1;
 		}
 
 		embeddable_data->sound = g_realloc (embeddable_data->sound,
-						  embeddable_data->sound_len
-						  + buffer->_length);
+						    embeddable_data->sound_len +
+						    buffer->_length);
 
 		memcpy (embeddable_data->sound + embeddable_data->sound_len,
 			buffer->_buffer, buffer->_length);
 
 		embeddable_data->sound_len += buffer->_length;
+		if (buffer->_length <= 0)
+			break;
 
-	} while (bytes_read > 0);
+		CORBA_free (buffer);
+	} while (1);
 
 	CORBA_free (buffer);
 	CORBA_exception_free (&ev);
 
-	if (bytes_read < 0)
-		return -1;
-
 	return 0;
 } /* stream_read */
 
@@ -287,7 +282,7 @@ static void
 embeddable_system_exception_cb (BonoboEmbeddable *embeddable, CORBA_Object corba_object,
 				CORBA_Environment *ev, gpointer data)
 {
-	bonobo_object_destroy (BONOBO_OBJECT (embeddable));
+	bonobo_object_unref (BONOBO_OBJECT (embeddable));
 }
 
 /*
@@ -297,7 +292,7 @@ static void
 view_system_exception_cb (BonoboView *view, CORBA_Object corba_object,
 			  CORBA_Environment *ev, gpointer data)
 {
-	bonobo_object_destroy (BONOBO_OBJECT (view));
+	bonobo_object_unref (BONOBO_OBJECT (view));
 }
 
 /*
@@ -464,7 +459,7 @@ init_server_factory (int argc, char **argv)
         gnome_init_with_popt_table("bonobo-audio-ulaw", VERSION,
 				   argc, argv,
 				   oaf_popt_options, 0, NULL); 
-	orb =oaf_init (argc, argv);
+	orb = oaf_init (argc, argv);
 #else
 	gnome_CORBA_init_with_popt_table (
 		"bonobo-audio-ulaw", VERSION,
