@@ -1,5 +1,11 @@
 #include <gnome.h>
+
+#if USING_OAF
+#include <liboaf/liboaf.h>
+#else
 #include <libgnorba/gnorba.h>
+#endif
+
 #include <bonobo.h>
 
 #ifndef __BONOBO_AUDIO_ULAW_H__
