@@ -97,9 +97,27 @@ typedef struct {
 	GtkWidget	 *table;
 } view_data_t;
 
+static void destroy_view_menus (view_data_t *view_data);
+
 /*
  * Utility functions.
  */
+static void
+destroy_view_menus (view_data_t *view_data)
+{
+	if ((view_data->uih == NULL) || (view_data->remote_uih == CORBA_OBJECT_NIL))
+		return;
+
+	bonobo_ui_component_rm (view_data->uih,
+				"/menu/text-plain/", NULL);
+
+	bonobo_object_release_unref (view_data->remote_uih, NULL);
+	bonobo_object_unref (BONOBO_OBJECT (view_data->uih));
+
+	view_data->remote_uih = CORBA_OBJECT_NIL;
+	view_data->uih = NULL;
+}
+
 static void
 destroy_view (view_data_t *view_data)
 {
@@ -254,11 +272,12 @@ progressive_update (bonobo_object_data_t *bonobo_object_data,
 		gtk_text_set_point (GTK_TEXT (view_data->text), 0);
 
 #ifndef NO_PROGRESS_METER
-		gtk_progress_bar_update (
-			GTK_PROGRESS_BAR (view_data->progress),
-			(float) bonobo_object_data->text_len /
-			bonobo_object_data->total_size);
-								 
+		if (bonobo_object_data->total_size != 0) {
+	                gtk_progress_bar_update (GTK_PROGRESS_BAR (view_data->progress),
+						 (float) bonobo_object_data->text_len /
+						 bonobo_object_data->total_size);
+		}
+
 #endif /* ! NO_PROGRESS_METER */
 
 		gtk_text_thaw (GTK_TEXT (view_data->text));
@@ -301,6 +320,7 @@ bonobo_object_destroy_cb (BonoboEmbeddable *bonobo_object,
 	g_free (bonobo_object_data);
 
 	running_objects--;
+	
 	if (running_objects > 0)
 		return;
 
@@ -457,31 +477,15 @@ create_view_menus (view_data_t *view_data)
 	bonobo_ui_component_add_verb (view_data->uih, "ClearText", (BonoboUIVerbFn) verb_ClearText_cb,
 				      view_data);
 
-	bonobo_ui_component_set_tree (view_data->uih, view_data->remote_uih, "/menu", parent, NULL);
+	bonobo_ui_component_set_tree (view_data->uih, "/menu", parent, NULL);
 
-	#if 0
+#if 0
 	bonobo_ui_handler_create_toolbar (uih, "Common");
 
 	bonobo_ui_handler_toolbar_new_item (uih, "/Common/item1", "item 1", NULL, -1,
 					   BONOBO_UI_HANDLER_PIXMAP_XPM_DATA, bolt_xpm,
 					   0, 0, NULL, NULL);
-	#endif
-}
-
-static void
-destroy_view_menus (view_data_t *view_data)
-{
-	if ((view_data->uih == NULL) || (view_data->remote_uih == CORBA_OBJECT_NIL))
-		return;
-
-	bonobo_ui_component_rm (view_data->uih, view_data->remote_uih,
-				"/menu/text-plain/", NULL);
-
-	bonobo_object_release_unref (view_data->remote_uih, NULL);
-	bonobo_object_unref (BONOBO_OBJECT (view_data->uih));
-
-	view_data->remote_uih = CORBA_OBJECT_NIL;
-	view_data->uih = NULL;
+#endif
 }
 
 static void
@@ -853,9 +857,9 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	}
 	running_objects++;
 
-	gtk_signal_connect_after (GTK_OBJECT (bonobo_object), "destroy",
-				  GTK_SIGNAL_FUNC (bonobo_object_destroy_cb),
-				  bonobo_object_data);
+	gtk_signal_connect (GTK_OBJECT (bonobo_object), "destroy",
+			    GTK_SIGNAL_FUNC (bonobo_object_destroy_cb),
+			    bonobo_object_data);
 
 	gtk_signal_connect (GTK_OBJECT (bonobo_object), "system_exception",
 			    GTK_SIGNAL_FUNC (embeddable_system_exception_cb),
