@@ -1,4 +1,4 @@
-/* $Id: component.c,v 1.12 2000/09/23 14:20:00 mmeeks Exp $ */
+/* $Id: component.c,v 1.14 2000/10/09 17:52:05 mmeeks Exp $ */
 
 #include "component.h"
 #include "embeddable-io.h"
@@ -103,28 +103,7 @@ static void
 component_user_context_cb (BonoboViewFrame  *view_frame,
 			   SampleClientSite *site)
 {
-	char  *executed_verb;
-	GList *l;
-
-	/*
-	 * See if the remote BonoboEmbeddable supports any verbs at
-	 * all.
-	 */
-	l = bonobo_client_site_get_verbs (BONOBO_CLIENT_SITE (site));
-	if (!l)
-		return;
-	bonobo_client_site_free_verbs (l);
-
-	/*
-	 * Popup the verb popup and execute the chosen verb.  This
-	 * function saves us the work of creating the menu, connecting
-	 * the callback, and executing the verb on the remove
-	 * BonoboView.  We could implement all this functionality
-	 * ourselves if we wanted.
-	 */
-	executed_verb = bonobo_view_frame_popup_verbs (view_frame);
-
-	g_free (executed_verb);
+	g_warning ("We need some standardized verb stuff here...");
 }
 
 void
