@@ -70,6 +70,12 @@ print_preview_cb (GtkWidget *caller, SampleApp *app)
 	sample_app_print_preview (app);
 }
 
+static void
+xml_dump_cb (GtkWidget *caller, SampleApp *app)
+{
+	bonobo_win_dump (BONOBO_WIN (app->app), "On request");
+}
+
 static void
 about_cb (GtkWidget *caller, SampleApp *app)
 {
@@ -104,6 +110,10 @@ static GnomeUIInfo sample_app_file_menu[] = {
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM (save_cb, NULL),
 	BONOBOUIINFO_PLACEHOLDER ("Placeholder"),
 
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_ITEM_NONE (N_("Xml dump"), NULL,
+			       xml_dump_cb),
+
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_NONE (N_("Print Pre_view"), NULL,
 			       print_preview_cb),
