@@ -19,14 +19,17 @@ sample_app_exit (SampleApp *app)
 
 	bonobo_object_unref (BONOBO_OBJECT (app->container));
 	bonobo_object_unref (BONOBO_OBJECT (app->ui_handler));
+	gtk_widget_destroy (app->app);
 
 	gtk_main_quit ();
 }
 
-static void
-delete_cb (GtkWidget *caller, SampleApp *app)
+static gint
+delete_cb (GtkWidget *caller, GdkEvent *event, SampleApp *app)
 {
 	sample_app_exit (app);
+
+	return TRUE;
 }
 
 static SampleApp *
@@ -34,21 +37,24 @@ sample_app_create (void)
 {
 	SampleApp *app = g_new0 (SampleApp, 1);
 	GtkWidget *app_widget;
-	
+
 	/* Create widgets */
-	app_widget = app->app = gnome_app_new ("sample-container",
-					       _("Sample Bonobo container"));
+	app_widget = app->app = bonobo_win_new ("sample-container",
+						_("Sample Bonobo container"));
+
 	app->box = gtk_vbox_new (FALSE, 10);
 
-	gtk_signal_connect (GTK_OBJECT (app_widget), "destroy", delete_cb, app);
+	gtk_signal_connect (GTK_OBJECT (app_widget), "delete_event",
+			    (GtkSignalFunc) delete_cb, app);
 
 	/* Do the packing stuff */
-	gnome_app_set_contents (GNOME_APP (app_widget), app->box);
+	bonobo_win_set_contents (BONOBO_WIN (app->app), app->box);
 	gtk_widget_set_usize (app_widget, 400, 600);
 
-	app->container = bonobo_container_new ();
+	app->container = bonobo_item_container_new ();
+
 	app->ui_handler = bonobo_ui_handler_new ();
-	bonobo_ui_handler_set_app (app->ui_handler, GNOME_APP (app_widget));
+	bonobo_ui_handler_set_app (app->ui_handler, BONOBO_WIN (app->app));
 
 	/* Create menu bar */
 	bonobo_ui_handler_create_menubar (app->ui_handler);
@@ -169,6 +175,8 @@ resolve_and_add (SampleApp *app, Bonobo_Moniker moniker, const char *interface)
 
 	if (!site)
 		g_warning ("Failed to add embeddable to app");
+
+	bonobo_object_release_unref (moniker, &ev);
 }
 
 /*
@@ -211,7 +219,9 @@ main (int argc, char **argv)
 	CORBA_Environment ev;
 	CORBA_ORB orb;
 
-	CORBA_exception_init (&ev);
+	free (malloc (8));
+
+ 	CORBA_exception_init (&ev);
 	gnome_init_with_popt_table ("container", VERSION,
 				    argc, argv, oaf_popt_options, 0, &ctx);
 
