@@ -9,16 +9,48 @@
  */
 #include <config.h>
 #include <gnome.h>
-
-#if USING_OAF
 #include <liboaf/liboaf.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
-
 #include <bonobo.h>
 
 Bonobo_PropertyBag pb = CORBA_OBJECT_NIL;
+BonoboPropertyListener *listener = NULL;
+
+static void
+prop_changed_cb (BonoboPropertyListener *listener, gchar *name, 
+		 BonoboArg *arg, GtkCList *clist)
+{
+	gchar *value;
+
+	value = g_strdup_printf ("%s", BONOBO_ARG_GET_BOOLEAN (arg) ? "TRUE" :"FALSE");
+
+	gtk_clist_set_text (clist, 0, 1, value);
+
+	g_free (value);
+}
+
+static void
+add_listener (GtkCList *clist)
+{
+	Bonobo_PropertyListener corba_listener;
+	CORBA_Environment ev;
+	
+	CORBA_exception_init (&ev);
+
+	/* Set up the change listener */
+	listener = bonobo_property_listener_new ();
+	gtk_signal_connect (GTK_OBJECT (listener), "prop_changed",
+			    GTK_SIGNAL_FUNC (prop_changed_cb), clist);
+
+	corba_listener = bonobo_object_corba_objref (BONOBO_OBJECT (listener));
+
+	Bonobo_PropertyBag_add_change_listener (pb, "running", corba_listener, &ev);
+
+	if (BONOBO_EX (&ev))
+		g_warning ("Listener exception: %s\n",
+			   bonobo_exception_get_text (&ev));
+
+	CORBA_exception_free (&ev);
+}
 
 static void
 populate_property_list (GtkWidget *bw, GtkCList *clist)
@@ -123,6 +155,8 @@ create_proplist (GtkWidget *bw)
  
 	populate_property_list (bw, GTK_CLIST (clist));
 
+	add_listener (GTK_CLIST (clist));
+
 	return clist;
 }
 
@@ -136,6 +170,16 @@ incr_calc (GtkButton *button, BonoboWidget *control)
 	bonobo_widget_set_property (control, "value", i, NULL);
 }
 
+static void
+toggle_clock (GtkButton *button, BonoboWidget *control)
+{
+	CORBA_boolean state;
+
+	bonobo_widget_get_property (control, "running", &state, NULL);
+
+	bonobo_widget_set_property (control, "running", !state, NULL);
+}
+
 static void
 app_destroy_cb (GtkWidget *app, BonoboUIHandler *uih)
 {
@@ -144,8 +188,12 @@ app_destroy_cb (GtkWidget *app, BonoboUIHandler *uih)
 		bonobo_object_release_unref (pb, NULL);
 	pb = CORBA_OBJECT_NIL;
 
+	if (listener)
+		bonobo_object_unref (BONOBO_OBJECT (listener));
+	listener = NULL;
+
 	gtk_main_quit ();
-	g_warning ("Main level %d\n", gtk_main_level ());
+/*	g_warning ("Main level %d\n", gtk_main_level ());*/
 }
 
 static int
@@ -158,42 +206,42 @@ app_delete_cb (GtkWidget *widget, GdkEvent *event, gpointer dummy)
 static guint
 container_create (void)
 {
-	GtkWidget       *app;
 	GtkWidget       *control;
 	GtkWidget       *proplist;
 	GtkWidget       *box;
 	GtkWidget       *button;
+	GtkWidget       *clock_button;
 	BonoboUIHandler *uih;
 	BonoboControlFrame *cf;
+	GtkWindow       *window;
+	GtkWidget       *app;
 
-	app = gnome_app_new ("sample-control-container",
-			     "Sample Bonobo Control Container");
-	gtk_window_set_default_size (GTK_WINDOW (app), 500, 440);
-	gtk_window_set_policy (GTK_WINDOW (app), TRUE, TRUE, FALSE);
+	app = bonobo_win_new ("sample-control-container",
+			      "Sample Bonobo Control Container");
 
+	window = GTK_WINDOW (app);
+	
 	uih = bonobo_ui_handler_new ();
 
-	gtk_signal_connect (GTK_OBJECT (app), "delete_event",
+	bonobo_ui_handler_set_app (uih, BONOBO_WIN (app));
+
+	gtk_window_set_default_size (window, 500, 440);
+	gtk_window_set_policy (window, TRUE, TRUE, FALSE);
+
+	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 			    GTK_SIGNAL_FUNC (app_delete_cb), NULL);
 
-	gtk_signal_connect (GTK_OBJECT (app), "destroy",
+	gtk_signal_connect (GTK_OBJECT (window), "destroy",
 			    GTK_SIGNAL_FUNC (app_destroy_cb), uih);
 
-	bonobo_ui_handler_set_app (uih, GNOME_APP (app));
 	bonobo_ui_handler_create_menubar (uih);
 
 	box = gtk_vbox_new (FALSE, 0);
-	gnome_app_set_contents (GNOME_APP (app), box);
+	bonobo_win_set_contents (BONOBO_WIN (app), box);
 
-#if USING_OAF
 	control = bonobo_widget_new_control (
 		"OAFIID:bonobo_calculator:fab8c2a7-9576-437c-aa3a-a8617408970f",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#else
-	control = bonobo_widget_new_control (
-  	        "control:calculator",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#endif
+		bonobo_ui_compat_get_container (uih));
 
 	gtk_box_pack_start (GTK_BOX (box), control, TRUE, TRUE, 0);
 
@@ -201,32 +249,26 @@ container_create (void)
 	gtk_signal_connect (GTK_OBJECT (button), "clicked",
 			    (GtkSignalFunc)incr_calc, control);
 
-#if USING_OAF
 	control = bonobo_widget_new_control (
 		"OAFIID:bonobo_clock:d42cc651-44ae-4f69-a10d-a0b6b2cc6ecc",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#else
-	control = bonobo_widget_new_control (
-		"control:clock",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#endif
+		bonobo_ui_compat_get_container (uih));
 
 	gtk_box_pack_start (GTK_BOX (box), control, TRUE, TRUE, 0);
 
+	clock_button = gtk_button_new_with_label ("Pause/Resume Clock");
+	gtk_signal_connect (GTK_OBJECT (clock_button), "clicked",
+			    (GtkSignalFunc) toggle_clock, control);
+
+	gtk_box_pack_start (GTK_BOX (box), clock_button, TRUE, TRUE, 0);
+
 	cf = bonobo_widget_get_control_frame (BONOBO_WIDGET (control));
 	pb = bonobo_control_frame_get_control_property_bag (cf, NULL);
 
 	proplist = create_proplist (control);
 
-#if USING_OAF
 	control = bonobo_widget_new_control (
 		"OAFIID:bonobo_entry_factory:ef3e3c33-43e2-4f7c-9ca9-9479104608d6",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#else
-	control = bonobo_widget_new_control (
-		"control:entry",
-		bonobo_object_corba_objref (BONOBO_OBJECT (uih)));
-#endif
+		bonobo_ui_compat_get_container (uih));
 
 	gtk_box_pack_start (GTK_BOX (box), control, TRUE, TRUE, 0);
 
@@ -234,7 +276,7 @@ container_create (void)
 
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
-	gtk_widget_show_all (app);
+	gtk_widget_show_all (GTK_WIDGET (window));
 
 	return FALSE;
 }
@@ -249,17 +291,10 @@ main (int argc, char **argv)
 	/* Encorage -lefence to play ball */
 	{ char *tmp = malloc (4); if (tmp) free (tmp); }
 
-#if USING_OAF
-        gnome_init_with_popt_table("sample-control-container", "0.0",
-				   argc, argv,
-				   oaf_popt_options, 0, NULL); 
+        gnome_init_with_popt_table ("sample-control-container", "0.0",
+				    argc, argv,
+				    oaf_popt_options, 0, NULL); 
 	orb = oaf_init (argc, argv);
-#else
-	gnome_CORBA_init_with_popt_table (
-      	"sample-control-container", "0.0",
-	&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
-	orb = gnome_CORBA_ORB ();
-#endif
 
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
 		g_error ("Could not initialize Bonobo");
