@@ -79,7 +79,7 @@ real_create_storage (BonoboStorage *storage, const CORBA_char *path,
 	BonoboStorageEFS *sefs;
 	EFSDir *dir;
 
-	if (!(dir = efs_dir_open (storage_efs->dir, path, EFS_CREATE|EFS_EXCL))) {
+	if (efs_dir_open (&dir, storage_efs->dir, path, EFS_CREATE|EFS_EXCL)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Storage_NameExists, NULL);
 		return NULL;
@@ -102,7 +102,7 @@ real_open_storage (BonoboStorage *storage, const CORBA_char *path,
 	BonoboStorageEFS *sefs;
 	EFSDir *dir;
 
-	if (!(dir = efs_dir_open (storage_efs->dir, path, 0))) {
+	if (efs_dir_open (&dir, storage_efs->dir, path, 0)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Storage_NotFound, NULL);
 		return NULL;
@@ -130,7 +130,7 @@ real_rename (BonoboStorage *storage, const CORBA_char *path,
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
 
-	if (!efs_rename (storage_efs->dir, path, new_path)) {
+	if (efs_rename (storage_efs->dir, path, new_path)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Storage_NotFound, NULL);
 	}
@@ -160,21 +160,21 @@ real_list_contents (BonoboStorage *storage, const CORBA_char *path,
 	list = Bonobo_Storage_directory_list__alloc();
 	CORBA_sequence_set_release (list, TRUE); 
 
-	if ((dir = efs_dir_open (storage_efs->dir, path, 0))) {
-		EFSDirEntry *de;
+	if (!efs_dir_open (&dir, storage_efs->dir, path, 0)) {
+		EFSDirEntry de;
 
-		for (i = 0; (de = efs_dir_read (dir)); i++)
+		for (i = 0; !(efs_dir_read (dir, &de)); i++)
 			;
 		efs_dir_close (dir);
 	} else
 		goto list_contents_except;
 		
-	if ((dir = efs_dir_open (storage_efs->dir, path, 0))) {
-		EFSDirEntry *de;
+	if (!efs_dir_open (&dir, storage_efs->dir, path, 0)) {
+		EFSDirEntry de;
 		char **buf = CORBA_sequence_CORBA_string_allocbuf (i);
 	
-		for (i = 0; (de = efs_dir_read (dir)); i++)
-			buf [i] = CORBA_string_dup (de->name);
+		for (i = 0; !(efs_dir_read (dir, &de)); i++)
+			buf [i] = CORBA_string_dup (de.name);
 
 		list->_length = i;
 		list->_buffer = buf;
@@ -197,7 +197,7 @@ real_erase (BonoboStorage *storage, const CORBA_char *path,
 {
 	BonoboStorageEFS *storage_efs = BONOBO_STORAGE_EFS (storage);
 
-	if (!efs_erase (storage_efs->dir, path)) {
+	if (efs_erase (storage_efs->dir, path)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Storage_NotFound, NULL);
 	}
@@ -264,7 +264,7 @@ bonobo_storage_efs_open (const gchar *path, gint flags, gint mode)
 
 	sefs = gtk_type_new (bonobo_storage_efs_get_type ());
 
-	if (!(sefs->dir = efs_open (path, flags, mode))) {
+	if (efs_open (&sefs->dir, path, flags, mode, NULL)) {
 		bonobo_object_unref (BONOBO_OBJECT (sefs));
 		return NULL;
 	}
