@@ -42,7 +42,7 @@ real_write (BonoboStream *stream, const Bonobo_Stream_iobuf *buffer,
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
 
 	if (efs_file_write (stream_efs->file, buffer->_buffer, 
-			    buffer->_length) == -1) {
+			    buffer->_length)) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Stream_IOError, NULL);
 		return 0;
@@ -58,7 +58,8 @@ real_read (BonoboStream *stream, CORBA_long count,
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
 	CORBA_octet *data;
-	CORBA_long bytes;
+	gint32 bytes_read;
+	EFSResult result;
 
 	if (count < 0) {
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
@@ -70,17 +71,17 @@ real_read (BonoboStream *stream, CORBA_long count,
 	CORBA_sequence_set_release (*buffer, TRUE);
 	data = CORBA_sequence_CORBA_octet_allocbuf (count);
 
-	bytes = efs_file_read (stream_efs->file, data, count);
-
-	if (bytes < 0) {
+	result = efs_file_read (stream_efs->file, data, count, &bytes_read);
+	
+	if (!result || (result == EFS_ERR_EOF)) {
+		(*buffer)->_buffer = data;
+		(*buffer)->_length = bytes_read;
+	} else {
 		CORBA_free (data);
 		CORBA_free (*buffer);
 		*buffer = NULL;
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
 				     ex_Bonobo_Stream_IOError, NULL);
-	} else {
-		(*buffer)->_buffer = data;
-		(*buffer)->_length = bytes;
 	}
 }
 
@@ -90,15 +91,22 @@ real_seek (BonoboStream *stream, CORBA_long offset, Bonobo_Stream_SeekType whenc
 {
 	BonoboStreamEFS *stream_efs = BONOBO_STREAM_EFS (stream);
 	int fw;
+	guint32 pos;
 
 	if (whence == Bonobo_Stream_SEEK_CUR)
-		fw = SEEK_CUR;
+		fw = EFS_SEEK_CUR;
 	else if (whence == Bonobo_Stream_SEEK_END)
-		fw = SEEK_END;
+		fw = EFS_SEEK_END;
 	else
-		fw = SEEK_SET;
+		fw = EFS_SEEK_SET;
 	
-	return efs_file_seek (stream_efs->file, offset, fw);
+	if (efs_file_seek (stream_efs->file, offset, fw, &pos)) {
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION, 
+				     ex_Bonobo_Stream_IOError, NULL);
+		return 0;
+	}
+	
+	return pos;
 }
 
 static void
@@ -186,7 +194,7 @@ bonobo_stream_efs_open_create (BonoboStorageEFS *storage_efs,
 	if (create)
 		flags |= EFS_CREATE;
   
-	if (!(stream_efs->file = efs_file_open (storage_efs->dir, path, flags))) {
+	if (efs_file_open (&stream_efs->file, storage_efs->dir, path, flags)) {
 		bonobo_object_unref (BONOBO_OBJECT (stream_efs));
 		return NULL;
 	}
