@@ -46,18 +46,18 @@ char *server_id = "OAFIID:test_bonobo_object:b1ff15bb-d54f-4814-ba53-d67d3afd70f
 
 typedef struct {
 	GtkWidget *app;
-	BonoboContainer *container;
+	BonoboItemContainer *container;
 	GtkWidget *box;
 	Bonobo_View view;
 	BonoboUIHandler *uih;
 } Application;
 
 static BonoboObjectClient *
-launch_server (BonoboClientSite *client_site, BonoboContainer *container, char *id)
+launch_server (BonoboClientSite *client_site, BonoboItemContainer *container, char *id)
 {
 	BonoboObjectClient *object_server;
 	
-	bonobo_container_add (container, BONOBO_OBJECT (client_site));
+	bonobo_item_container_add (container, BONOBO_OBJECT (client_site));
 
 	printf ("Launching...\n");
 	object_server = bonobo_object_activate (id, 0);
@@ -76,15 +76,15 @@ launch_server (BonoboClientSite *client_site, BonoboContainer *container, char *
 }
 
 static BonoboObjectClient *
-launch_server_moniker (BonoboClientSite  *client_site,
-		       BonoboContainer   *container,
-		       Bonobo_Moniker     moniker,
-		       CORBA_Environment *ev)
+launch_server_moniker (BonoboClientSite    *client_site,
+		       BonoboItemContainer *container,
+		       Bonobo_Moniker       moniker,
+		       CORBA_Environment   *ev)
 {
 	char *moniker_name;
 	BonoboObjectClient *object_server;
 	
-	bonobo_container_add (container, BONOBO_OBJECT (client_site));
+	bonobo_item_container_add (container, BONOBO_OBJECT (client_site));
 
 	moniker_name = bonobo_moniker_client_get_name (moniker, ev);
 	printf ("Launching moniker '%s' ...\n", moniker_name);
@@ -687,13 +687,13 @@ exit_cmd (void)
 }
 
 static GnomeUIInfo container_text_plain_menu [] = {
-	GNOMEUIINFO_ITEM_NONE (N_("_Add a new text/plain component"), NULL,
+	GNOMEUIINFO_ITEM_NONE (N_("_Add a new text\\plain component"), NULL,
 			       add_text_cmd),
 	GNOMEUIINFO_ITEM_NONE (
-	N_("_Send progressive data to an existing text/plain component"),
+	N_("_Send progressive data to an existing text\\plain component"),
 			       NULL, send_text_cmd),
 	GNOMEUIINFO_ITEM_NONE (
-		N_("Add a new _view to an existing text/plain component"),
+		N_("Add a new _view to an existing text\\plain component"),
 			       NULL, add_text_view),
 	GNOMEUIINFO_END
 };
@@ -710,17 +710,17 @@ static GnomeUIInfo container_paint_menu [] = {
 
 static GnomeUIInfo container_image_png_menu [] = {
 	GNOMEUIINFO_ITEM_NONE (
-		N_("_Add a new application/x-png component"), NULL,
+		N_("_Add a new application\\x-png component"), NULL,
 		add_image_cmd),
  	GNOMEUIINFO_ITEM_NONE (
-		N_("Add a new _view to an existing application/x-png component"),
+		N_("Add a new _view to an existing application\\x-png component"),
 			       NULL, add_image_view),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo container_image_pdf_menu [] = {
 	GNOMEUIINFO_ITEM_NONE (
-		N_("_Add a new application/x-pdf component"), NULL,
+		N_("_Add a new application\\x-pdf component"), NULL,
 		add_pdf_cmd),
 	GNOMEUIINFO_END
 };
@@ -751,9 +751,9 @@ static GnomeUIInfo container_canvas_menu [] = {
 
 static GnomeUIInfo container_main_menu [] = {
 	GNOMEUIINFO_MENU_FILE_TREE (container_file_menu),
-	GNOMEUIINFO_SUBTREE (N_("_text/plain"), container_text_plain_menu),
-	GNOMEUIINFO_SUBTREE (N_("_image/x-png"), container_image_png_menu),
-	GNOMEUIINFO_SUBTREE (N_("_app/x-pdf"), container_image_pdf_menu),
+	GNOMEUIINFO_SUBTREE (N_("_text\\plain"), container_text_plain_menu),
+	GNOMEUIINFO_SUBTREE (N_("_image\\x-png"), container_image_png_menu),
+	GNOMEUIINFO_SUBTREE (N_("_app\\x-pdf"), container_image_pdf_menu),
 	GNOMEUIINFO_SUBTREE (N_("paint sample"), container_paint_menu),
 	GNOMEUIINFO_SUBTREE (N_("Gnumeric"), container_gnumeric_menu),
 	GNOMEUIINFO_SUBTREE (N_("Canvas-based"), container_canvas_menu),
@@ -767,20 +767,21 @@ application_new (void)
 	BonoboUIHandlerMenuItem *menu_list;
 
 	app = g_new0 (Application, 1);
-	app->app = gnome_app_new ("test-container",
-				  "Sample Container Application");
-	app->container = BONOBO_CONTAINER (bonobo_container_new ());
-
+	app->container = BONOBO_ITEM_CONTAINER (bonobo_item_container_new ());
 	app->box = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (app->box);
-	gnome_app_set_contents (GNOME_APP (app->app), app->box);
+
+	app->app = bonobo_win_new ("test-container",
+				   "Sample Container Application");
+
+	bonobo_win_set_contents (BONOBO_WIN (app->app), app->box);
+
+	app->uih = bonobo_ui_handler_new ();
+	bonobo_ui_handler_set_app (app->uih, BONOBO_WIN (app->app));
 
 	/*
 	 * Create the menus.
 	 */
-	app->uih = bonobo_ui_handler_new ();
-
-	bonobo_ui_handler_set_app (app->uih, GNOME_APP (app->app));
 	bonobo_ui_handler_create_menubar (app->uih);
 
 	menu_list = bonobo_ui_handler_menu_parse_uiinfo_list_with_data (container_main_menu, app);
