@@ -19,6 +19,7 @@
  *
  *----------------------------------------------------------------------*/
 
+#include <config.h>
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
 #include "bonobrowser.h"
@@ -133,13 +134,13 @@ register_object (gchar *server_id, gchar *creation_type, gchar **interfaces,
 	/* creation_type will be exe, factory or shlib */
  	if (!contains_non_whitespace (creation_type)) {
 		if (user_interaction_allowed)
-			message_box ("Please fill in the creation type.");
+			message_box (_("Please fill in the creation type."));
 		return FALSE;
 	}
 	/* location_info will be a filename or the goad_id of a factory */
  	if (!contains_non_whitespace (location_info)) {
 		if (user_interaction_allowed)
-			message_box ("Please fill in the creation method.");
+			message_box (_("Please fill in the creation method."));
 		return FALSE;
 	}
 
@@ -151,13 +152,13 @@ register_object (gchar *server_id, gchar *creation_type, gchar **interfaces,
 	
 	if (!filename) {
 		if (user_interaction_allowed)
-			message_box ("The server_id is empty.");
+			message_box (_("The server_id is empty."));
 		return FALSE;
 	}
 	
 	if (strlen (filename) < 1) {
 		if (user_interaction_allowed)
-			message_box ("The server_id is empty.");
+			message_box (_("The server_id is empty."));
 		g_free (filename);
 		return FALSE;
 	}
@@ -178,7 +179,7 @@ register_object (gchar *server_id, gchar *creation_type, gchar **interfaces,
 			fprintf (f, "[%s]\ntype=%s\nrepo_id=",
 				 server_id, creation_type);
 
-			for (;*interfaces; *interfaces++) {
+			for (;*interfaces; interfaces++) {
 				fprintf (f, "%s ", *interfaces);
 			}
 
@@ -190,13 +191,13 @@ register_object (gchar *server_id, gchar *creation_type, gchar **interfaces,
 		}
 		else /* fopen failed */
 			if (user_interaction_allowed) {
-				message_box ("Can't open file %s for writing: %s",
+				message_box (_("Can't open file %s for writing: %s"),
 					     filename_fq, strerror(errno));
 			}
 		
 	} else if (fopen_rtn == 0) {/* file exists, so let's not overwrite it */
 		if (user_interaction_allowed) 
-			message_box ("The file %s already exists!",
+			message_box (_("The file %s already exists!"),
 				     filename_fq);
 		
 		else
@@ -381,12 +382,14 @@ delete_clist_item (GtkWidget *widget,
 	gint row;
 
 	if (event->keyval != GDK_Delete)
-		return;
+		return FALSE;
 	
 	if (clist->selection) {	
 		row = (gint)g_list_nth (clist->selection, 0)->data;
 		gtk_clist_remove (clist, row);
 	}
+
+	return FALSE;
 } /* delete_clist_item */
 
 
@@ -422,13 +425,13 @@ interface_section_new(object_registration_info* reg_info)
 
 	radio_button = gtk_radio_button_new_with_label (
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button)),
-		"Local");
+		_("Local"));
 	gtk_signal_connect (GTK_OBJECT (radio_button), "clicked",
 			    GTK_SIGNAL_FUNC(interface_local_clicked),
 			    reg_info);			
 	gtk_box_pack_start (GTK_BOX (hbox), radio_button, FALSE, TRUE, 0);
 
-	button = gtk_button_new_with_label ("New");
+	button = gtk_button_new_with_label (_("New"));
 	reg_info->iface_combo = GTK_COMBO (gtk_combo_new());
 	
 	gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -457,7 +460,7 @@ interface_section_new(object_registration_info* reg_info)
 	
 	interface_idl_clicked(idl_radio_button, reg_info);	
 
-	button = gtk_button_new_with_label ("Add");
+	button = gtk_button_new_with_label (_("Add"));
 	gtk_signal_connect (GTK_OBJECT (button), "clicked",
 			    GTK_SIGNAL_FUNC(add_interface_to_list),
 			    reg_info);			
@@ -556,7 +559,7 @@ server_id_section_new(object_registration_info* reg_info)
 
 	radio_button = gtk_radio_button_new_with_label (
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button)),
-		"Local");
+		_("Local"));
 
 	gtk_signal_connect (GTK_OBJECT (radio_button), "clicked",
 			    GTK_SIGNAL_FUNC(server_local_clicked),
@@ -636,7 +639,7 @@ create_activation_type_file_dialog(GtkWidget *unused1,
 {
 	object_registration_info* reg_info = p;
 	GtkFileSelection *fs = GTK_FILE_SELECTION (
-		gtk_file_selection_new ("file selection dialog"));
+		gtk_file_selection_new (_("file selection dialog")));
 
 	gtk_file_selection_hide_fileop_buttons (fs);
 
@@ -681,7 +684,7 @@ creation_type_section_new(object_registration_info* reg_info)
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 5);
 
 	radio_button = gtk_radio_button_new_with_label (
-		NULL, "factory");
+		NULL, _("factory"));
 	gtk_signal_connect (GTK_OBJECT (radio_button), "clicked",
 			    GTK_SIGNAL_FUNC (activation_factory_clicked),
 			    reg_info);
@@ -691,7 +694,7 @@ creation_type_section_new(object_registration_info* reg_info)
 	
 	radio_button = gtk_radio_button_new_with_label (
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button)),
-		"exe");
+		_("exe"));
 
 	gtk_signal_connect (GTK_OBJECT (radio_button), "clicked",
 			    GTK_SIGNAL_FUNC(activation_exe_clicked),
@@ -701,7 +704,7 @@ creation_type_section_new(object_registration_info* reg_info)
 
 	radio_button = gtk_radio_button_new_with_label (
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button)),
-		"shlib");
+		_("shlib"));
 
 	gtk_signal_connect (GTK_OBJECT (radio_button), "clicked",
 			    GTK_SIGNAL_FUNC(activation_shlib_clicked),
@@ -710,7 +713,7 @@ creation_type_section_new(object_registration_info* reg_info)
 	gtk_box_pack_start (GTK_BOX (hbox), radio_button, FALSE, TRUE, 0);
 
 	reg_info->creation_browse_button = GTK_BUTTON (
-		gtk_button_new_with_label ("Browse"));
+		gtk_button_new_with_label (_("Browse")));
 	gtk_signal_connect (GTK_OBJECT (reg_info->creation_browse_button), "clicked",
 			    GTK_SIGNAL_FUNC(activation_type_browse),
 			    reg_info);
@@ -809,15 +812,15 @@ object_browser_register_new_object(void)
 				    GTK_SIGNAL_FUNC(delete_reg_info),
 				    reg_info);
 
-		gtk_window_set_title (GTK_WINDOW (window), "New Object");
+		gtk_window_set_title (GTK_WINDOW (window), _("New Object"));
 
-		iface_frame = gtk_frame_new("Interface(s)");
+		iface_frame = gtk_frame_new(_("Interface(s)"));
 		gtk_container_add (GTK_CONTAINER (iface_frame),
 				   interface_section_new(reg_info));
-		serverid_frame = gtk_frame_new("Server ID");
+		serverid_frame = gtk_frame_new(_("Server ID"));
 		gtk_container_add (GTK_CONTAINER (serverid_frame),
 				   server_id_section_new(reg_info));	
-		creation_frame = gtk_frame_new("Creation method");
+		creation_frame = gtk_frame_new(_("Creation method"));
 		gtk_container_add (GTK_CONTAINER (creation_frame),
 				   creation_type_section_new(reg_info));	
 	
@@ -832,7 +835,7 @@ object_browser_register_new_object(void)
 		gtk_box_pack_start (GTK_BOX (vbox),
 				    hbox,
 				    FALSE, TRUE, 5);		
-		label = gtk_label_new ("Description:");
+		label = gtk_label_new (_("Description:"));
 		gtk_box_pack_start (GTK_BOX (hbox),
 				    label,
 				    FALSE, TRUE, 5);		
@@ -844,7 +847,7 @@ object_browser_register_new_object(void)
 		/* add in `register object' btn */
 		{
 			GtkWidget *button, *hbox;
-			button = gtk_button_new_with_label ("Register this object");
+			button = gtk_button_new_with_label (_("Register this object"));
 
 			hbox = gtk_hbox_new (FALSE, 0);
 			gtk_box_pack_start (GTK_BOX (vbox),
